(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     24645,        858]
NotebookOptionsPosition[     21820,        764]
NotebookOutlinePosition[     22881,        803]
CellTagsIndexPosition[     22838,        800]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Campos de velocidades, l\[IAcute]neas de corriente y superficies \
equipotenciales\
\>", "Section",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[CellGroupData[{

Cell["\<\
Campos de velocidades y l\[IAcute]neas de corriente\
\>", "Subsection",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[TextData[{
 "Dado el campo de velocidades (digamos, de un fluido) en el espacio ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["V", "\[RightVector]"], "(", 
     RowBox[{"x", ",", "y", ",", "z"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["V", "x"], "(", 
       RowBox[{"x", ",", "y", ",", "z"}], ")"}], 
      OverscriptBox["i", "^"]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["V", "y"], "(", 
       RowBox[{"x", ",", "y", ",", "z"}], ")"}], 
      OverscriptBox["j", "^"]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["V", "z"], "(", 
       RowBox[{"x", ",", "y", ",", "z"}], ")"}], 
      OverscriptBox["k", "^"]}]}]}], TraditionalForm]]],
 ", las l\[IAcute]neas de corriente (digamos, las trayectorias de las part\
\[IAcute]culas del fluido) son tangentes a dicho campo en cada punto del \
espacio, y vienen dadas por el sistema de ecuaciones diferenciales:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"d", " ", 
      OverscriptBox["r", "\[RightVector]"]}], 
     RowBox[{"d", " ", "t"}]], "=", 
    RowBox[{
     OverscriptBox["V", "\[RightVector]"], " ", "\[DoubleLongRightArrow]", 
     "  "}]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"{", GridBox[{
           {
            RowBox[{
             FractionBox[
              RowBox[{"d", " ", "x"}], 
              RowBox[{"d", " ", "t"}]], "=", 
             SubscriptBox["V", "x"]}]},
           {
            RowBox[{
             FractionBox[
              RowBox[{"d", " ", "y"}], 
              RowBox[{"d", " ", "t"}]], "=", 
             SubscriptBox["V", "y"]}]},
           {
            RowBox[{
             FractionBox[
              RowBox[{"d", " ", "z"}], 
              RowBox[{"d", " ", "t"}]], "=", 
             SubscriptBox["V", "z"]}]}
          }]}],
        ShowAutoStyles->False],
       #& ], "   ", "\[DoubleLongRightArrow]", "d"}], " ", "t"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"d", " ", "x"}], 
      SubscriptBox["V", "x"]], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"d", " ", "y"}], 
       SubscriptBox["V", "y"]], "=", 
      FractionBox[
       RowBox[{"d", " ", "z"}], 
       SubscriptBox["V", "z"]]}]}]}], TraditionalForm]]],
 " \n\nPor ejemplo, tomemos el campo de velocidades en el plano dado por ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["V", "\[RightVector]"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "y"}], ",", "x"}], ")"}]}], TraditionalForm]]],
 ". Una representaci\[OAcute]n gr\[AAcute]fica del mismo"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{"<<", "Graphics`PlotField`"}], "\[IndentingNewLine]", 
 RowBox[{"remolino", "=", 
  RowBox[{"PlotVectorField", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "y"}], ",", "x"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[1]:="],

Cell["\<\
nos muestra un \"v\[OAcute]rtice o remolino\". Se trata de un campo \
incompresible (de divergencia nula) pero NO irrotacional (o NO \"conservativo\
\"); en efecto:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"<<", "Calculus`VectorAnalysis`"}], " "}], "\[IndentingNewLine]", 
 RowBox[{"Div", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "y"}], ",", "x", ",", "0"}], "}"}], ",", 
   RowBox[{"Cartesian", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Curl", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "y"}], ",", "x", ",", "0"}], "}"}], ",", 
   RowBox[{"Cartesian", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}]}], "Input",
 CellLabel->"In[3]:="],

Cell["\<\
Las l\[IAcute]neas de corriente son las soluciones de:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"t", ",", "x0", ",", "y0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lincor", "[", 
   RowBox[{"t_", ",", "x0_", ",", "y0_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], ",", 
     RowBox[{"y", "[", "t", "]"}]}], "}"}], "/.", 
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "t", "]"}], "==", 
        RowBox[{"-", 
         RowBox[{"y", "[", "t", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "'"}], "[", "t", "]"}], "==", 
        RowBox[{"x", "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{"x", "[", "0", "]"}], "==", "x0"}], ",", 
       RowBox[{
        RowBox[{"y", "[", "0", "]"}], "==", "y0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]}]}]}], "Input",
 CellLabel->"In[6]:="],

Cell["\<\
Tomemos unos cuantos miembros de esta familia biparam\[EAcute]trica de \
soluciones en una tabla\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"familia", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"lincor", "[", 
      RowBox[{"t", ",", "x0", ",", "y0"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[8]:="],

Cell["\<\
y represent\[EAcute]mosla en un diagrama \
\>", "Text"],

Cell[BoxData[
 RowBox[{"lineas", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"familia", ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[9]:="],

Cell["\<\
Superponiendo el campo de velocidades y las l\[IAcute]neas de corriente \
tenemos:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"remolino", ",", "lineas"}], "]"}]], "Input",
 CellLabel->"In[10]:="],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Dibujar el campo de velocidades y las l\[IAcute]neas de corriente del campo \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["V", "\[RightVector]"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["y", "2"], ",", "x"}], ")"}]}], TraditionalForm]]],
 ". \[DownQuestion]Es incompresible?, \[DownQuestion]es irrotacional?."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Dibujar el campo de velocidades y las l\[IAcute]neas de corriente del campo \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["V", "\[RightVector]"], "(", 
     RowBox[{"x", ",", "y", ",", "z"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", 
       SuperscriptBox["x", "2"]}], ",", 
      RowBox[{"-", "y"}], ",", 
      SuperscriptBox["z", "3"]}], ")"}]}], TraditionalForm]]],
 ". \[DownQuestion]Es incompresible?, \[DownQuestion]es irrotacional?."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Campos irrotacionales: superficies equipotenciales. Ecuaciones de Laplace y \
Poisson\
\>", "Subsection",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[TextData[{
 "Consideremos el caso en que el campo de velocidades sea irrotacional \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["\[Del]", "\[RightVector]"], 
     RowBox[{"\[Times]", 
      RowBox[{
       OverscriptBox["V", "\[RightVector]"], "(", 
       RowBox[{"x", ",", "y", ",", "z"}], ")"}]}]}], "=", 
    RowBox[{
     RowBox[{
      OverscriptBox["0", "\[RightVector]"], " ", "\[DoubleLongRightArrow]", 
      RowBox[{
       OverscriptBox["V", "\[RightVector]"], "(", 
       RowBox[{"x", ",", "y", ",", "z"}], ")"}]}], "=", 
     RowBox[{
      OverscriptBox["\[Del]", "\[RightVector]"], 
      RowBox[{"U", "(", 
       RowBox[{"x", ",", "y", ",", "z"}], ")"}]}]}]}], TraditionalForm]]],
 "\n\ndonde ",
 StyleBox["U ",
  FontSlant->"Italic"],
 "es la funci\[OAcute]n potencial. El campo ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["V", "\[RightVector]"], TraditionalForm]]],
 " es perpendicular a las",
 " superficies (curvas, en el plano) de nivel ",
 StyleBox["U(x,y,z)=cte ",
  FontSlant->"Italic"],
 "o \"superficies equipotenciales\". As\[IAcute], las l\[IAcute]neas de \
corriente son ortogonales a las superficies (curvas, en el plano) \
equipotenciales. Por ejemplo, consideremos el campo ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["V", "\[RightVector]"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"y", ",", "x"}], ")"}]}], TraditionalForm]]]
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[
 RowBox[{"campo", "=", 
  RowBox[{"PlotVectorField", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"y", ",", "x"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellLabel->"In[11]:="],

Cell["Veamos que se trata de un campo incompresible e irrotacional", "Text"],

Cell[BoxData[{
 RowBox[{"Div", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"y", ",", "x", ",", "0"}], "}"}], ",", 
   RowBox[{"Cartesian", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Curl", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"y", ",", "x", ",", "0"}], "}"}], ",", 
   RowBox[{"Cartesian", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}]}], "Input",
 CellLabel->"In[12]:="],

Cell[TextData[{
 "El potencial ",
 StyleBox["U ",
  FontSlant->"Italic"],
 " del que deriva el campo de velocidades es ",
 StyleBox["U(x,y)=xy. ",
  FontSlant->"Italic"],
 " En efecto:"
}], "Text"],

Cell[BoxData[
 RowBox[{"Grad", "[", 
  RowBox[{
   RowBox[{"x", " ", "y"}], ",", 
   RowBox[{"Cartesian", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[14]:="],

Cell[TextData[{
 "Veamos c\[OAcute]mo obtenerlo en general. Definamos el campo de velocidades \
e integremos ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "x"], TraditionalForm]]],
 " en ",
 StyleBox["x",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"v", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"{", " ", 
   RowBox[{"y", ",", "x"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"U", "=", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "x"], 
    RowBox[{
     RowBox[{
      RowBox[{"v", "[", 
       RowBox[{"t", ",", "y"}], "]"}], "\[LeftDoubleBracket]", "1", 
      "\[RightDoubleBracket]"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "+", 
   RowBox[{"f", "[", "y", "]"}]}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[15]:="],

Cell[TextData[{
 "Obtenemos U salvo una funci\[OAcute]n arbitraria ",
 StyleBox["f(y). ",
  FontSlant->"Italic"],
 " Para evaluar la funci\[OAcute]n arbitraria hacemos:"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], "U"}], "==", 
     RowBox[{
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[LeftDoubleBracket]", "2", 
      "\[RightDoubleBracket]"}]}], ",", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}]}], "]"}], ";"}], "\n", 
 RowBox[{"dfy", "=", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], "/.", 
     RowBox[{"Flatten", "[", "%", "]"}]}], "]"}], "/.", 
   RowBox[{"y", "\[Rule]", "t"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", "y"], 
  RowBox[{"dfy", 
   RowBox[{"\[DifferentialD]", "t"}]}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[17]:="],

Cell[TextData[{
 "Obteniendo ",
 StyleBox["f(y)=0\[DoubleRightArrow] U(x,y)=xy.",
  FontSlant->"Italic"],
 " Hagamos una representaci\[OAcute]n gr\[AAcute]fica de las curvas \
equipotenciales ",
 StyleBox["U(x,y)=xy=cte",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{"curvequip", "=", 
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"x", " ", "y"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"ContourShading", "->", "False"}], ",", 
    RowBox[{"ContourStyle", "->", 
     RowBox[{"Dashing", "[", 
      RowBox[{"{", ".02", "}"}], "]"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[20]:="],

Cell["y de las l\[IAcute]neas de corriente:", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"t", ",", "x0", ",", "y0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lincor", "[", 
    RowBox[{"t_", ",", "x0_", ",", "y0_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], ",", 
      RowBox[{"y", "[", "t", "]"}]}], "}"}], "/.", 
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"x", "'"}], "[", "t", "]"}], "==", 
         RowBox[{"y", "[", "t", "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}], "==", 
         RowBox[{"x", "[", "t", "]"}]}], ",", 
        RowBox[{
         RowBox[{"x", "[", "0", "]"}], "==", "x0"}], ",", 
        RowBox[{
         RowBox[{"y", "[", "0", "]"}], "==", "y0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], ",", 
        RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"familia", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"lincor", "[", 
      RowBox[{"t", ",", "x0", ",", "y0"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"lineas", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"familia", ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}], "Input",
 CellLabel->"In[21]:="],

Cell["\<\
Superponiendo las l\[IAcute]neas de corriente a las curvas equipotenciales \
\>", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"lineas", ",", "curvequip"}], "]"}]], "Input",
 CellLabel->"In[25]:="],

Cell["\<\
Vemos que se trata efectivamente de trayectorias ortogonales.\
\>", "Text"],

Cell[TextData[{
 "Recuerde que un campo conservativo ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["V", "\[RightVector]"], "=", 
    RowBox[{
     OverscriptBox["\[Del]", "\[RightVector]"], "U"}]}], TraditionalForm]]],
 " e incompresible ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      OverscriptBox["\[Del]", "\[RightVector]"], "\[FilledVerySmallSquare]"}], 
     OverscriptBox["V", "\[RightVector]"]}], "=", "0"}], TraditionalForm]]],
 " satisface la ",
 StyleBox["ecuaci\[OAcute]n de Laplace ",
  FontSlant->"Italic"],
 "\n\n",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Del]", "\[RightVector]"], TraditionalForm]]],
 "\[FilledVerySmallSquare]",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["\[Del]", "\[RightVector]"], "U"}], "=", 
    RowBox[{"\[CapitalDelta]U", "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "U"}], 
        RowBox[{"\[PartialD]", 
         SuperscriptBox["x", "2"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "U"}], 
        RowBox[{"\[PartialD]", 
         SuperscriptBox["y", "2"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "U"}], 
        RowBox[{"\[PartialD]", 
         SuperscriptBox["z", "2"]}]]}], "=", "0", " "}]}]}], 
   TraditionalForm]]],
 "\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      FormBox[
       OverscriptBox["\[Del]", "\[RightVector]"],
       TraditionalForm], "\[FilledVerySmallSquare]"}], 
     FormBox[
      OverscriptBox["\[Del]", "\[RightVector]"],
      TraditionalForm]}], "=", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FormBox[
        OverscriptBox["\[Del]", "\[RightVector]"],
        TraditionalForm], ")"}], "2"], "=", 
     RowBox[{"\[CapitalDelta]", "=", 
      RowBox[{
       FractionBox[
        SuperscriptBox["\[PartialD]", "2"], 
        RowBox[{"\[PartialD]", 
         SuperscriptBox["x", "2"]}]], 
       RowBox[{"+", 
        RowBox[{
         FractionBox[
          SuperscriptBox["\[PartialD]", "2"], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["y", "2"]}]], 
         RowBox[{"+", 
          FractionBox[
           SuperscriptBox["\[PartialD]", "2"], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["z", "2"]}]]}]}]}]}]}]}]}], TraditionalForm]]],
 " es el operador Laplaciano. Si el campo no es incompresible ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      OverscriptBox["\[Del]", "\[RightVector]"], "\[FilledVerySmallSquare]"}], 
     OverscriptBox["V", "\[RightVector]"]}], "=", "f"}], TraditionalForm]]],
 ", entonces la ecuaci\[OAcute]n que se satisface es la de ",
 StyleBox["Poisson",
  FontSlant->"Italic"],
 "\n\n",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Del]", "\[RightVector]"], TraditionalForm]]],
 "\[FilledVerySmallSquare]",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["\[Del]", "\[RightVector]"], "U"}], "=", 
    RowBox[{"\[CapitalDelta]U", "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "U"}], 
        RowBox[{"\[PartialD]", 
         SuperscriptBox["x", "2"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "U"}], 
        RowBox[{"\[PartialD]", 
         SuperscriptBox["y", "2"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "U"}], 
        RowBox[{"\[PartialD]", 
         SuperscriptBox["z", "2"]}]]}], "=", "f", " "}]}]}], 
   TraditionalForm]]],
 "\n\nPor ejemplo, veamos que el potencial anterior ",
 StyleBox["U(x,y)=xy ",
  FontSlant->"Italic"],
 " verifica la ecuaci\[OAcute]n de Laplace:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[
 RowBox[{"Laplacian", "[", 
  RowBox[{
   RowBox[{"x", " ", "y"}], ",", 
   RowBox[{"Cartesian", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[26]:="],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Dado el campo de velocidades ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["V", "\[RightVector]"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "="}], TraditionalForm]]],
 "{",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"2", "x", " ", "y"}], ",", 
    RowBox[{
     SuperscriptBox["x", "2"], "-", 
     SuperscriptBox["y", "2"]}]}], TraditionalForm]]],
 "}, demostrar que es irrotacional y encontrar el potencial ",
 StyleBox[" U ",
  FontSlant->"Italic"],
 "del que deriva. Representar el campo, las l\[IAcute]neas de corriente y las \
curvas equipotenciales, y superponer dichos gr\[AAcute]ficos para cerciorarse \
de que 1) el campo es tangente a las l\[IAcute]neas de corriente y 2) las l\
\[IAcute]neas de corriente son ortogonales a las curvas equipotenciales. \
\[DownQuestion]Qu\[EAcute] ecuaci\[OAcute]n verifica al potencial, la de \
Laplace o la de Poisson?"
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingStartingPageNumber->157,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      OptionValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      OptionValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"FacingPages"->True,
"FirstPageHeader"->False,
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{72, 72}, {57.5625, 57.5625}}},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Textbook.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 204, 7, 82, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[796, 33, 176, 6, 37, "Subsection",
 Evaluatable->False],
Cell[975, 41, 2849, 92, 202, "Text",
 Evaluatable->False],
Cell[3827, 135, 581, 18, 47, "Input"],
Cell[4411, 155, 188, 4, 23, "Text"],
Cell[4602, 161, 576, 17, 69, "Input"],
Cell[5181, 180, 78, 2, 23, "Text"],
Cell[5262, 184, 1034, 32, 49, "Input"],
Cell[6299, 218, 120, 3, 23, "Text"],
Cell[6422, 223, 413, 13, 28, "Input"],
Cell[6838, 238, 65, 2, 23, "Text"],
Cell[6906, 242, 332, 10, 28, "Input"],
Cell[7241, 254, 106, 3, 25, "Text"],
Cell[7350, 259, 116, 3, 30, "Input"],
Cell[CellGroupData[{
Cell[7491, 266, 34, 0, 37, "Subsubsection"],
Cell[7528, 268, 430, 13, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7995, 286, 34, 0, 37, "Subsubsection"],
Cell[8032, 288, 523, 16, 26, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8604, 310, 210, 7, 43, "Subsection",
 Evaluatable->False],
Cell[8817, 319, 1575, 47, 143, "Text",
 Evaluatable->False],
Cell[10395, 368, 417, 13, 30, "Input"],
Cell[10815, 383, 76, 0, 25, "Text"],
Cell[10894, 385, 448, 13, 50, "Input"],
Cell[11345, 400, 197, 8, 25, "Text"],
Cell[11545, 410, 200, 6, 30, "Input"],
Cell[11748, 418, 243, 9, 25, "Text"],
Cell[11994, 429, 614, 20, 62, "Input"],
Cell[12611, 451, 181, 5, 25, "Text"],
Cell[12795, 458, 942, 30, 82, "Input"],
Cell[13740, 490, 256, 8, 25, "Text"],
Cell[13999, 500, 510, 15, 30, "Input"],
Cell[14512, 517, 53, 0, 25, "Text"],
Cell[14568, 519, 1762, 55, 90, "Input"],
Cell[16333, 576, 99, 2, 25, "Text"],
Cell[16435, 580, 117, 3, 30, "Input"],
Cell[16555, 585, 85, 2, 25, "Text"],
Cell[16643, 589, 3936, 131, 248, "Text",
 Evaluatable->False],
Cell[20582, 722, 205, 6, 30, "Input"],
Cell[CellGroupData[{
Cell[20812, 732, 34, 0, 37, "Subsubsection"],
Cell[20849, 734, 931, 25, 60, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

