(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     93448,       3265]
NotebookOptionsPosition[     85265,       3018]
NotebookOutlinePosition[     86352,       3058]
CellTagsIndexPosition[     86309,       3055]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Geometr\[IAcute]a de curvas y superficies\
\>", "Section",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[CellGroupData[{

Cell["\<\
Geometr\[IAcute]a de curvas en el plano y el espacio\
\>", "Subsection",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[CellGroupData[{

Cell["Longitud de una curva", "Subsubsection"],

Cell[TextData[{
 "Nos centraremos por ahora en curvas planas definidas en forma \
param\[EAcute]trica, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["r", "\[RightVector]"], "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", "(", "t", ")"}], ",", 
       RowBox[{"y", "(", "t", ")"}]}], ")"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "(", "t", ")"}], 
       OverscriptBox["i", "\[RightVector]"]}], "+", 
      RowBox[{
       RowBox[{"y", "(", "t", ")"}], 
       OverscriptBox["j", "\[RightVector]"]}]}]}]}], TraditionalForm]]],
 ", en vez de la forma expl\[IAcute]cita ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    RowBox[{"f", "(", "x", ")"}]}], TraditionalForm]]],
 ". Aqu\[IAcute]  ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 " es el ",
 StyleBox["par\[AAcute]metro ",
  FontSlant->"Italic"],
 " (\[AAcute]ngulo, tiempo, etc) que nos da la posici\[OAcute]n ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["r", "\[RightVector]"], TraditionalForm]]],
 " para cada valor de ",
 StyleBox[" t. ",
  FontSlant->"Italic"],
 "Por ejemplo, las expresiones:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"x", ",", "y", ",", "r", ",", "t"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"x", "[", "t_", "]"}], ":=", 
  RowBox[{"Cos", "[", "t", "]"}]}], "\n", 
 RowBox[{
  RowBox[{"y", "[", "t_", "]"}], ":=", 
  RowBox[{"Sin", "[", "t", "]"}]}], "\n", 
 RowBox[{
  RowBox[{"r", "[", "t_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "[", "t", "]"}], ",", 
    RowBox[{"y", "[", "t", "]"}]}], "}"}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[1]:="],

Cell["\<\
definen las ecuaciones param\[EAcute]tricas de una circunferencia de radio 1, \
cuya representaci\[OAcute]n gr\[AAcute]fica puede hacerse mediante el comando:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"circ", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], ",", 
      RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"2", "Pi"}]}], "}"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[5]:="],

Cell["\<\
Comencemos por encontrar la longitud de dicha curva. Recu\[EAcute]rdese que \
el esp\[IAcute]ritu del c\[AAcute]lculo radica en aproximar el arco de curva \
por segmentos rectil\[IAcute]neos. Por ejemplo, dividamos nuestra \
circunferencia en n=10 segmentos\
\>", "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"decacirc", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"r", "[", "i", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", 
         RowBox[{"2", "Pi"}], ",", 
         FractionBox[
          RowBox[{"2", "Pi"}], "n"]}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"DisplayFunction", "->", "Identity"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"decacirc", ",", "circ", ",", 
    RowBox[{"DisplayFunction", "->", "$DisplayFunction"}]}], "]"}], 
  ";"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[6]:="],

Cell[TextData[{
 "N\[OAcute]tese que \[EAcute]sta es una aproximaci\[OAcute]n \"decente\" a \
la circunferencia. Fabriquemos una tabla con las longitudes ",
 StyleBox["longseg[[i]]",
  FontWeight->"Bold"],
 " de cada uno de estos ",
 StyleBox["i=1,...,10",
  FontWeight->"Bold"],
 " segmentos y calculemos la suma de las longitudes de estos 10 segmentos:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"longseg", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r", "[", 
          RowBox[{"i", "+", 
           FractionBox[
            RowBox[{"2", "Pi"}], "n"]}], "]"}], "-", 
         RowBox[{"r", "[", "i", "]"}]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r", "[", 
          RowBox[{"i", "+", 
           FractionBox[
            RowBox[{"2", "Pi"}], "n"]}], "]"}], "-", 
         RowBox[{"r", "[", "i", "]"}]}], ")"}]}]], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "Pi"}], "-", 
        RowBox[{"2", 
         RowBox[{"Pi", "/", "n"}]}]}], ",", 
       FractionBox[
        RowBox[{"2", "Pi"}], "n"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"N", "[", 
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], 
    RowBox[{"Length", "[", "longseg", "]"}]], 
   RowBox[{
   "longseg", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
  "]"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[9]:="],

Cell["\<\
(Repita  el alumno este c\[AAcute]lculo para 20 y 30 segmentos)\
\>", "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York",
 FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
 "Conforme el n\[UAcute]mero de segmentos",
 StyleBox[" ",
  FontWeight->"Bold"],
 "(",
 StyleBox["n",
  FontWeight->"Bold"],
 ")",
 " crece, la suma de sus longitudes se aproxima a la longitud exacta de la \
circunferencia de radio 1 que, como sabemos, es 2\[Pi]\[TildeTilde]6.28319. \
Recordemos c\[OAcute]mo se calcula la longitud exacta de una curva  mediante \
el c\[AAcute]lculo integral. Llamemos ",
 Cell[BoxData[
  FormBox[
   RowBox[{"d", " ", "l"}], TraditionalForm]]],
 "  a la longitud de un segmento infinitesimal. Usando el teorema de Pit\
\[AAcute]goras vemos que:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"d", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"d", " ", 
       SuperscriptBox["y", "2"]}]}], "=", 
     RowBox[{"d", " ", 
      SuperscriptBox["l", "2"]}]}], ","}], TraditionalForm]]],
 "  es decir,  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"d", " ", "l"}], "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"d", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"d", " ", 
       SuperscriptBox["y", "2"]}]}]]}], TraditionalForm]]],
 ", o escrito en forma param\[EAcute]trica ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"d", " ", "l"}], "=", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], 
         SuperscriptBox[
          RowBox[{"(", "t", ")"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"y", "'"}], 
         SuperscriptBox[
          RowBox[{"(", "t", ")"}], "2"]}]}]], 
      StyleBox["dt",
       FontSlant->"Italic"]}], "=", 
     RowBox[{"||", 
      RowBox[{
       RowBox[{
        OverscriptBox["r", "\[RightVector]"], "'"}], 
       RowBox[{"(", "t", ")"}]}], "||", 
      StyleBox["dt",
       FontSlant->"Italic"]}]}]}], TraditionalForm]]],
 "\ndonde ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"||", 
     OverscriptBox["v", "\[RightVector]"], "||"}], "=", 
    SqrtBox[
     RowBox[{
      OverscriptBox["v", "\[RightVector]"], ".", 
      OverscriptBox["v", "\[RightVector]"]}]]}], TraditionalForm]]],
 " es la norma de un vector.\n\nSumando las longitudes de todos estos \
segmentos diferenciales  tenemos que:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"longitud", "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], 
     RowBox[{"||", 
      RowBox[{
       RowBox[{
        OverscriptBox["r", "\[RightVector]"], "'"}], 
       RowBox[{"(", "t", ")"}]}], "||", 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], TraditionalForm]]],
 "\n\ndonde  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["r", "\[RightVector]"], "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "(", "t", ")"}], "i"}], "+", 
     RowBox[{
      RowBox[{"y", "(", "t", ")"}], "j"}]}]}], TraditionalForm]]],
 " es una curva derivable en el intervalo ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}],
   FontSlant->"Italic"]]],
 ". En nuestro caso, la longitud de la circunferencia es:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 TextAlignment->Left,
 TextJustification->1,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", 
   RowBox[{" ", 
    RowBox[{"2", "\[Pi]"}]}]], 
  RowBox[{
   SqrtBox[
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "t"], " ", 
      RowBox[{"r", "[", "t", "]"}]}], ".", 
     RowBox[{
      SubscriptBox["\[PartialD]", "t"], " ", 
      RowBox[{"r", "[", "t", "]"}]}]}]], 
   RowBox[{"\[DifferentialD]", "t"}]}]}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[11]:="],

Cell[TextData[{
 "Obteniendo el resultado que ya esper\[AAcute]bamos. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " dispone del  comando ",
 StyleBox["ArcLengthFactor",
  FontWeight->"Bold"],
 " para calcular la expresi\[OAcute]n ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], " ", 
     RowBox[{"r", "[", "t", "]"}]}], ".", 
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], " ", 
     RowBox[{"r", "[", "t", "]"}]}]}]]],
  ShowGroupOpener->True,
  AspectRatioFixed->True,
  FontFamily->"New York",
  FontWeight->"Bold"],
 ". En efecto:"
}], "Text",
 ShowGroupOpener->True],

Cell[BoxData[{
 RowBox[{
  SqrtBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], " ", 
     RowBox[{"r", "[", "t", "]"}]}], ".", 
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], " ", 
     RowBox[{"r", "[", "t", "]"}]}]}]], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Calculus`VectorAnalysis`"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ArcLengthFactor", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", "t", "]"}], ",", 
      RowBox[{"Sin", "[", "t", "]"}], ",", "0"}], "}"}], ",", "t", ",", 
    "Cartesian"}], "]"}], "//", "Simplify"}]}], "Input",
 CellLabel->"In[12]:="],

Cell[TextData[{
 "nos dan el mismo resultado (observe que ha sido necesario cargar el paquete \
",
 StyleBox["<<Calculus`VectorAnalysis`",
  FontWeight->"Bold"],
 " y escribir la curva plana ",
 StyleBox["{Cos[t],Sin[t]}",
  FontWeight->"Bold"],
 " como una curva en el espacio ",
 StyleBox["{Cos[t],Sin[t],0}",
  FontWeight->"Bold"],
 " a\[NTilde]adiendo la coordenada z=0). La ventaja del comando ",
 StyleBox["ArcLengthFactor",
  FontWeight->"Bold"],
 " es que permite curvas dadas en otros sistemas de coordenadas que no sea el \
cartesiano sin mas que modificar la opci\[OAcute]n ",
 StyleBox["Cartesian",
  FontWeight->"Bold"],
 " por ",
 StyleBox["Spherical, Cylindrical",
  FontWeight->"Bold"],
 ", etc. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicios", "Subsubsection"],

Cell[TextData[{
 "1) El c\[AAcute]lculo de este tipo de integrales suele ser  bastante \
complicado, \[DownExclamation]incluso para ",
 StyleBox["Mathematica!. ",
  FontSlant->"Italic"],
 " Por ejemplo, intente  calcular la longitud de una elipse de semiejes 2 y \
3:\n\n",
 StyleBox["x[t_]:=2Cos[t]\ny[t_]:=3Sin[t]\nr[t_]:={x[t],y[t]}\n",
  FontWeight->"Bold"],
 "\nprimero de forma aproximada (para 10 y 20 segmentos) y ",
 "despu\[EAcute]s",
 " de forma exacta. Se dar\[AAcute] cuenta que la integral no es expresable \
en t\[EAcute]rminos de funciones elementales. Pruebe entonces una integraci\
\[OAcute]n num\[EAcute]rica.\n\n2) Intente tambi\[EAcute]n el c\[AAcute]lculo \
exacto de la longitud de la par\[AAcute]bola",
 StyleBox[" y=",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]],
  FontSlant->"Italic"],
 "  para ",
 StyleBox["x\[Element][0,1]\n\n",
  FontSlant->"Italic"],
 "3) Vea si es capaz de hacer lo propio para una curva en tres dimensiones \
como la h\[EAcute]lice:\n\n",
 StyleBox["x[t_]:=Cos[t]\ny[t_]:=Sin[t]\nz[t_]:=t\nr[t_]:={x[t],y[t],z[t]}\n\n\
",
  FontWeight->"Bold"],
 "entre t=0 y t=2\[Pi]."
}], "Text",
 ShowGroupOpener->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Parametrizaci\[OAcute]n de una curva por su longitud de arco\
\>", "Subsubsection",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York",
 FontSize->12],

Cell[TextData[{
 "Hemos visto que la longitud ",
 StyleBox["l(t) ",
  FontSlant->"Italic"],
 "del arco de una curva ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["r", "\[RightVector]"], TraditionalForm]]],
 " entre un punto ",
 StyleBox["a",
  FontSlant->"Italic"],
 " y otro arbitrario ",
 StyleBox["t",
  FontSlant->"Italic"],
 " se define como una funci\[OAcute]n  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"l", "(", "t", ")"}], "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "t"], 
     RowBox[{"||", 
      RowBox[{
       RowBox[{
        OverscriptBox["r", "\[RightVector]"], "'"}], 
       RowBox[{"(", "w", ")"}]}], "||", 
      RowBox[{
       RowBox[{"\[DifferentialD]", "w"}], "."}]}]}]}], TraditionalForm]]],
 "  Podemos crear nuestro propio comando para calcular longitudes de arcos de \
curva de la siguiente manera: "
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"r", ",", "x", ",", "y", ",", "a", ",", "b"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"norma", "[", "x_", "]"}], ":=", 
  SqrtBox[
   RowBox[{"x", ".", "x"}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"longitudarco", "[", 
   RowBox[{"r_", ",", "a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{
   SubsuperscriptBox["\[Integral]", "a", "b"], 
   RowBox[{
    RowBox[{"norma", "[", 
     RowBox[{
      SubscriptBox["\[PartialD]", "#1"], 
      RowBox[{"r", "[", "#1", "]"}]}], "]"}], 
    RowBox[{"\[DifferentialD]", "#1"}]}]}]}]}], "Input",
 CellLabel->"In[15]:="],

Cell[TextData[StyleBox["Por ejemplo, para la h\[EAcute]lice",
 FontFamily->"New York"]], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "[", "t_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Cos", "[", "t", "]"}], ",", 
    RowBox[{"Sin", "[", "t", "]"}], ",", 
    FractionBox["t", "3"]}], "}"}]}], "\n", 
 RowBox[{
  RowBox[{"rtrayectoria", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], ",", 
       RowBox[{"Sin", "[", "t", "]"}], ",", 
       FractionBox["t", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[Pi]"}], ",", 
       RowBox[{"4", " ", "\[Pi]"}]}], "}"}]}], "]"}]}], ";"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[18]:="],

Cell[TextData[{
 "tenemos que la longitud de un arco de h\[EAcute]lice entre ",
 StyleBox["w=-4\[Pi] ",
  FontSlant->"Italic"],
 "y ",
 StyleBox["w=t ",
  FontSlant->"Italic"],
 "es"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"l", "[", "t_", "]"}], ":=", 
  RowBox[{"longitudarco", "[", 
   RowBox[{"r", ",", 
    RowBox[{
     RowBox[{"-", "4"}], " ", "\[Pi]"}], ",", "t"}], "]"}]}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[20]:="],

Cell[TextData[{
 "Bajo ciertas condiciones, esta longitud de arco ",
 StyleBox["l(t) ",
  FontSlant->"Italic"],
 " tiene inversa ",
 StyleBox["t(l), ",
  FontSlant->"Italic"],
 " la cual podemos calcular mediante:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"l", "[", "t", "]"}], "==", "l"}], ",", "t"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"t", "[", "l_", "]"}], "=", 
  RowBox[{"t", "/.", 
   RowBox[{
   "%", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[21]:="],

Cell[TextData[{
 "La curva ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["r", "\[RightVector]"], "(", "t", ")"}], TraditionalForm]]],
 " puede ahora parametrizarse en funci\[OAcute]n de la longitud ",
 StyleBox[" l ",
  FontSlant->"Italic"],
 "como ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["u", "\[RightVector]"], "(", "l", ")"}], "=", 
    RowBox[{
     OverscriptBox["r", "\[RightVector]"], "(", 
     RowBox[{"t", "(", "l", ")"}], ")"}]}], TraditionalForm]]],
 ". Puesto que  ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 " va de ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "4"}], "\[Pi]"}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "\[Pi]"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["l", TraditionalForm]]],
 " ir\[AAcute] de  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "(", 
    RowBox[{
     RowBox[{"-", "4"}], "\[Pi]"}], ")"}], TraditionalForm]]],
 " a ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "(", 
    RowBox[{"4", "\[Pi]"}], ")"}], TraditionalForm]]],
 ".  Veamos qu\[EAcute] aspecto tiene la h\[EAcute]lice parametrizada por la \
longitud de arco:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", "[", "l_", "]"}], ":=", 
  RowBox[{"r", "[", 
   RowBox[{"t", "[", "l", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"u", "[", "l", "]"}], "]"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[23]:="],

Cell[TextData[{
 "Veamos cu\[AAcute]l es la longitud de arco para ",
 StyleBox["t=4\[Pi]  ",
  FontSlant->"Italic"],
 "(para ",
 StyleBox["t=-4\[Pi]  ",
  FontSlant->"Italic"],
 " la longitud debe ser cero, \[DownQuestion]por qu\[EAcute]?):"
}], "Text"],

Cell[BoxData[{
 RowBox[{"l", "[", 
  RowBox[{
   RowBox[{"-", "4"}], " ", "\[Pi]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"l", "[", 
    RowBox[{"4", " ", "\[Pi]"}], "]"}], "//", "N"}], 
  "\[IndentingNewLine]"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[25]:="],

Cell[TextData[{
 "Si queremos representar la trayectoria recorrida por un m\[OAcute]vil que \
se mueve sobre la h\[EAcute]lice cuando \[EAcute]ste ha recorrido",
 StyleBox[" l=10 ",
  FontSlant->"Italic"],
 "unidades m\[EAcute]tricas, entonces debemos utilizar la parametrizaci\
\[OAcute]n en funci\[OAcute]n de la longitud del arco de curva:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"utrayectoria", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", "l", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[27]:="],

Cell[TextData[{
 "Comparemos con la trayectoria ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["r", "\[RightVector]"], "(", "t", ")"}], TraditionalForm]]],
 " parametrizada en funci\[OAcute]n de ",
 StyleBox["t",
  FontSlant->"Italic"]
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"GraphicsArray", "[", 
    RowBox[{"{", 
     RowBox[{"rtrayectoria", ",", "utrayectoria"}], "}"}], "]"}], "]"}], 
  ";"}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[28]:="],

Cell[TextData[{
 "La diferencia est\[AAcute] en que ",
 StyleBox["l=10",
  FontSlant->"Italic"],
 " implica ",
 StyleBox["t<4\[Pi]",
  FontSlant->"Italic"],
 ". En efecto:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", "[", "10", "]"}], "//", "N"}]], "Input",
 CellLabel->"In[29]:="],

Cell[TextData[{
 "es decir, una longitud de arco",
 StyleBox[" l=10 ",
  FontSlant->"Italic"],
 "es equivalente a ",
 StyleBox["t\[TildeTilde]-3.07954",
  FontSlant->"Italic"],
 "; ",
 "o sea",
 ", el m\[OAcute]vil ha recorrido algo mas del 37% de su trayectoria entre ",
 StyleBox["t=-4\[Pi]",
  FontSlant->"Italic"],
 " y ",
 StyleBox["t=4\[Pi]. ",
  FontSlant->"Italic"],
 "Otro aspecto interesante de parametrizar una curva por la longitud de arco \
es que el vector tangente siempre tiene longitud 1; en efecto:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["u", "\[Prime]",
   MultilineFunction->None], "[", "l", "]"}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[30]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   SuperscriptBox["u", "\[Prime]",
    MultilineFunction->None], "[", "l", "]"}], "]"}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[31]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  SqrtBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["u", "\[Prime]",
      MultilineFunction->None], "[", "l", "]"}], ".", 
    RowBox[{
     SuperscriptBox["u", "\[Prime]",
      MultilineFunction->None], "[", "l", "]"}]}]], "]"}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[32]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Un m\[OAcute]vil se desplaza sobre una par\[AAcute]bola ",
 StyleBox["y=",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " desde ",
 StyleBox["x=0",
  FontSlant->"Italic"],
 " hasta ",
 StyleBox["x=4. ",
  FontSlant->"Italic"],
 "Proporcione una expresi\[OAcute]n de la posici\[OAcute]n ",
 StyleBox["{x(l),y(l)}",
  FontSlant->"Italic"],
 " del m\[OAcute]vil en funci\[OAcute]n de la longitud ",
 StyleBox["l",
  FontSlant->"Italic"],
 " del arco de curva recorrido. Haga una representaci\[OAcute]n \
gr\[AAcute]fica de la trayectoria del m\[OAcute]vil desde ",
 StyleBox["x=0",
  FontSlant->"Italic"],
 " hasta ",
 StyleBox["x=4",
  FontSlant->"Italic"],
 " y de la trayectoria desde ",
 StyleBox["l=0 ",
  FontSlant->"Italic"],
 "hasta",
 StyleBox[" l=15.",
  FontSlant->"Italic"],
 " \[DownQuestion]Cu\[AAcute]l es el espacio total recorrido desde ",
 StyleBox["x=0",
  FontSlant->"Italic"],
 " hasta ",
 StyleBox["x=4",
  FontSlant->"Italic"],
 " ?."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Vector tangente y normal a una curva: curvatura y torsi\[OAcute]n\
\>", "Subsubsection"],

Cell[TextData[{
 "Veamos que ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["v", "\[RightVector]"], "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{
      OverscriptBox["r", "\[RightVector]"], "'"}], 
     RowBox[{"(", "t", ")"}]}]}], TraditionalForm]]],
 " es un vector tangente a la curva ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["r", "\[RightVector]"], "(", "t", ")"}], TraditionalForm]]],
 ". Como ejemplo utilizaremos la par\[AAcute]bola:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"x", ",", "y", ",", "r", ",", "v"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"x", "[", "t_", "]"}], ":=", "t"}], "\n", 
 RowBox[{
  RowBox[{"y", "[", "t_", "]"}], ":=", 
  SuperscriptBox["t", "2"]}], "\n", 
 RowBox[{
  RowBox[{"r", "[", "t_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "[", "t", "]"}], ",", 
    RowBox[{"y", "[", "t", "]"}]}], "}"}]}], "\n", 
 RowBox[{
  RowBox[{"parabola", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"r", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"Dashing", "[", 
       RowBox[{"{", "0.02", "}"}], "]"}]}]}], "]"}]}], ";"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[33]:="],

Cell["El vector tangente unitario se calcula como:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vu", "[", "t_", "]"}], ":=", 
  FractionBox[
   RowBox[{
    SuperscriptBox["r", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], 
   SqrtBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["r", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], ".", 
     RowBox[{
      SuperscriptBox["r", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]]]}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"vu", "[", "t", "]"}], "]"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[38]:="],

Cell["\<\
Representemos gr\[AAcute]ficamente el vector unitario tangente a la par\
\[AAcute]bola en varios puntos\
\>", "Text"],

Cell[BoxData[{
 StyleBox[
  RowBox[{"<<", "Graphics`PlotField`"}],
  FontWeight->"Bold"], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vlistplot", "=", 
   RowBox[{"ListPlotVectorField", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r", "[", "i", "]"}], ",", 
         RowBox[{"vu", "[", "i", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], 
  ";"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[40]:="],

Cell["El vector normal unitario se calcula como:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nu", "[", "t_", "]"}], ":=", 
  FractionBox[
   RowBox[{
    SuperscriptBox["vu", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], 
   SqrtBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["vu", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], ".", 
     RowBox[{
      SuperscriptBox["vu", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]]]}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"nu", "[", "t", "]"}], "]"}]}], "Input",
 CellLabel->"In[42]:="],

Cell["\<\
Representemos gr\[AAcute]ficamente el vector unitario normal a la \
par\[AAcute]bola en varios puntos\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nlistplot", "=", 
   RowBox[{"ListPlotVectorField", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r", "[", "i", "]"}], ",", 
         RowBox[{"nu", "[", "i", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[44]:="],

Cell["\<\
Juntando las tres gr\[AAcute]ficas obtenemos:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"parabola", ",", "vlistplot", ",", "nlistplot"}], "}"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "10"}], "}"}]}]}], "]"}], ";"}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[45]:="],

Cell[TextData[{
 "Que nos muestra el \"biedro\" de Frenet en los puntos x=-3,-2,-1,0,1,2,3. \
Observe que  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["n", "\[RightVector]"], "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       OverscriptBox["v", "\[RightVector]"], "'"}], 
      RowBox[{
       RowBox[{"(", "t", ")"}], "/"}]}], "||", 
     RowBox[{
      RowBox[{
       OverscriptBox["v", "\[RightVector]"], "'"}], 
      RowBox[{"(", "t", ")"}]}], "||"}]}], TraditionalForm]]],
 " es perpendicular al vector tangente, lo que implica que es perpendicular a \
la curva. El vector normal unitario ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["n", "\[RightVector]"], "(", "t", ")"}], " "}], 
   TraditionalForm]]],
 " puede tambi\[EAcute]n escribirse como: \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["n", "\[RightVector]"], "(", "t", ")"}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{
       OverscriptBox["v", "\[RightVector]"], "'"}], 
      RowBox[{"(", "t", ")"}]}], 
     RowBox[{
      RowBox[{"\[Kappa]", "(", "t", ")"}], " ", "||", 
      RowBox[{
       RowBox[{
        OverscriptBox["r", "\[RightVector]"], "'"}], 
       RowBox[{"(", "t", ")"}]}], "||"}]]}], TraditionalForm]]],
 ",     (",
 "demu\[EAcute]strelo",
 ")\n\ndonde",
 StyleBox[" \[Kappa](t) ",
  FontSlant->"Italic"],
 "es la ",
 StyleBox["curvatura. ",
  FontSlant->"Italic"],
 " Recordemos que la curvatura representa la variaci\[OAcute]n del vector \
tangente con respecto a la longitud de arco: \n\n\[Kappa]",
 StyleBox["(l)",
  FontSlant->"Italic"],
 "=||",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"d", " ", 
     OverscriptBox["v", "\[RightVector]"]}], 
    RowBox[{"d", " ", "l"}]], TraditionalForm]]],
 "||. \n\nComo funci\[OAcute]n de ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 ", la regla de la cadena nos da:\n\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Kappa]", "(", "t", ")"}], "=", 
    RowBox[{"||", 
     RowBox[{
      RowBox[{
       OverscriptBox["v", "\[RightVector]"], "'"}], 
      RowBox[{"(", "t", ")"}]}], "||", 
     RowBox[{"/", 
      RowBox[{"||", 
       RowBox[{
        RowBox[{
         OverscriptBox["r", "\[RightVector]"], "'"}], 
        RowBox[{"(", "t", ")"}]}], "||"}]}]}]}], TraditionalForm]]],
 ".\n\nLa idea es que, si la variaci\[OAcute]n de direcci\[OAcute]n del \
vector tangente es muy grande, entonces la curva se curva (\"dobla\") de \
forma considerable. \n\nSi la curva est\[AAcute] parametrizada por la \
longitud de arco ",
 StyleBox["l,",
  FontSlant->"Italic"],
 " el vector normal es simplemente:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["n", "\[RightVector]"], "(", "l", ")"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"d", " ", 
       RowBox[{
        OverscriptBox["v", "\[RightVector]"], "(", "l", ")"}]}], 
      RowBox[{"d", " ", "l"}]], "/", 
     RowBox[{"\[Kappa]", "(", "l", ")"}]}]}], TraditionalForm]]],
 ".   (demu\[EAcute]strelo)\n\nLo mismo que hemos definido un comando para la \
longitud del arco de curva, podemos definir otro para la curvatura de la \
siguiente manera:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"curvatura", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"vu", ",", "k"}], "}"}], ",", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{"vu", "[", "t", "]"}], "=", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"r", "[", "t", "]"}], ",", "t"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"r", "[", "t", "]"}], ",", "t"}], "]"}], ".", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"r", "[", "t", "]"}], ",", "t"}], "]"}]}], "]"}]}]}], ";",
       "\n", "    ", 
      RowBox[{"k", "=", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"vu", "[", "t", "]"}], ",", "t"}], "]"}], ".", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"vu", "[", "t", "]"}], ",", "t"}], "]"}]}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"r", "[", "t", "]"}], ",", "t"}], "]"}], ".", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"r", "[", "t", "]"}], ",", "t"}], "]"}]}], "]"}]}]}], ";",
       "\n", "    ", 
      RowBox[{"Return", "[", "k", "]"}]}]}], "]"}]}],
  FontWeight->"Bold"]], "Input",
 CellLabel->"In[46]:="],

Cell["\<\
Por ejemplo, la curvatura de la par\[AAcute]bola es:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"curvatura", "[", 
   RowBox[{"r", ",", "t"}], "]"}], "]"}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[47]:="],

Cell[TextData[{
 "que se simplifica a ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "/", 
    SqrtBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"4", 
         SuperscriptBox["t", "2"]}]}], ")"}], "3"]]}], TraditionalForm]]],
 " .  Representemos el valor de la curvatura de la par\[AAcute]bola en funci\
\[OAcute]n del par\[AAcute]metro ",
 StyleBox["t:",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"2", "/", 
    SqrtBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"4", 
         SuperscriptBox["t", "2"]}]}], ")"}], "3"]]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[48]:="],

Cell[TextData[{
 "Vemos que la par\[AAcute]bola ",
 StyleBox["y=",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " se curva m\[AAcute]s \"intensamente\" en las cercan\[IAcute]as de ",
 StyleBox["x=0",
  FontSlant->"Italic"],
 ". \n\nPara curvas en el espacio disponemos de m\[AAcute]s recursos gr\
\[AAcute]ficos para visualizar la curvatura, tales como el uso de colores. \
Por ejemplo, consideremos una h\[EAcute]lice resultante al ",
 "enrollar",
 " un cable a lo largo de un cilindro el\[IAcute]ptico de semiejes 1 y 2:"
}], "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"x", ",", "y", ",", "z", ",", "r", ",", "v"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"x", "[", "t_", "]"}], ":=", 
  RowBox[{"Cos", "[", "t", "]"}]}], "\n", 
 RowBox[{
  RowBox[{"y", "[", "t_", "]"}], ":=", 
  RowBox[{"2", 
   RowBox[{"Sin", "[", "t", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"z", "[", "t_", "]"}], ":=", "t"}], "\n", 
 RowBox[{
  RowBox[{"h", "[", "t_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "[", "t", "]"}], ",", 
    RowBox[{"y", "[", "t", "]"}], ",", 
    RowBox[{"z", "[", "t", "]"}]}], "}"}]}], "\n", 
 RowBox[{
  RowBox[{"heliceliptica", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"h", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", "Pi"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.531"}], ",", " ", "1.647", ",", " ", "3.507"}], 
       "}"}]}]}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[49]:="],

Cell["Su curvatura es:", "Text"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"curvatura", "[", 
   RowBox[{"h", ",", "t"}], "]"}], "]"}]], "Input",
 CellLabel->"In[55]:="],

Cell[TextData[{
 "Representemos gr\[AAcute]ficamente la curvatura como una funci\[OAcute]n de \
",
 StyleBox["t:",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"13", "-", 
        RowBox[{"3", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"7", "+", 
          RowBox[{"3", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}], "2"]]]}], 
    SqrtBox[
     RowBox[{"7", "+", 
      RowBox[{"3", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "t"}], "]"}]}]}]]], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "Pi"}]}], "}"}], ",", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[56]:="],

Cell[TextData[{
 "Vemos que la curvatura presenta m\[AAcute]ximos en t=\[Pi]/2 y t=3\[Pi]/2. \
Definiendo un color distinto para la curvatura de la h\[EAcute]lice el\
\[IAcute]ptica en cada punto ",
 StyleBox["t",
  FontSlant->"Italic"],
 " como:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"colorhelip", "[", "t_", "]"}], ":=", 
  RowBox[{"Hue", "[", 
   FractionBox[
    RowBox[{"2", " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"13", "-", 
        RowBox[{"3", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"7", "+", 
          RowBox[{"3", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}], "2"]]]}], 
    SqrtBox[
     RowBox[{"7", "+", 
      RowBox[{"3", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "t"}], "]"}]}]}]]], "]"}]}]], "Input",
 CellLabel->"In[57]:="],

Cell["\<\
Podemos crear un gr\[AAcute]fico de dicha curva coloreado de acuerdo con la \
intensidad de la curvatura por medio de:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "t", "]"}], ",", 
     RowBox[{"2", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", "t", ",", 
     RowBox[{"colorhelip", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "Pi"}]}], "}"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<h\[EAcute]lice el\[IAcute]ptica coloreada seg\[UAcute]n \
curvatura\>\""}], ",", 
   RowBox[{"ViewPoint", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.531"}], ",", " ", "1.647", ",", " ", "3.507"}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[58]:="],

Cell["\<\
de manera que las zonas rojas se corresponden con puntos de mayor curvatura \
que las verdes. Tambi\[EAcute]n podemos usar el recurso del grosor de l\
\[IAcute]nea\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"grosorhelip", "[", "t_", "]"}], ":=", 
  RowBox[{"Thickness", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"13", "-", 
         RowBox[{"3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "t"}], "]"}]}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"7", "+", 
           RowBox[{"3", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}], "2"]]]}], 
     SqrtBox[
      RowBox[{"7", "+", 
       RowBox[{"3", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}]}]]], "/", "15"}], "]"}]}]], "Input",
 CellLabel->"In[59]:="],

Cell["\<\
(n\[OAcute]tese que hemos dividido por 15 para no tener un grosor excesivo) \
para dar idea de las zonas de mayor curvatura, como:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "t", "]"}], ",", 
     RowBox[{"2", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", "t", ",", 
     RowBox[{"grosorhelip", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "Pi"}]}], "}"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<h\[EAcute]lice el\[IAcute]ptica coloreada seg\[UAcute]n \
curvatura\>\""}], ",", 
   RowBox[{"ViewPoint", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.531"}], ",", " ", "1.647", ",", " ", "3.507"}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[60]:="],

Cell[TextData[{
 "de manera que las zonas de mayor curvatura aparecen con un grosor de l\
\[IAcute]nea mayor. \n\nTambi\[EAcute]n podemos definir un comando para la \
torsi\[OAcute]n \[Tau](t)=",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"||", 
     RowBox[{
      RowBox[{
       OverscriptBox["r", "\[RightVector]"], "'"}], "\[Times]", 
      RowBox[{
       OverscriptBox["r", "\[RightVector]"], "''"}], "\[FilledCircle]", 
      RowBox[{
       OverscriptBox["r", "\[RightVector]"], "''"}]}], "||"}], 
    RowBox[{"||", 
     RowBox[{
      OverscriptBox["r", "\[RightVector]"], "\[FilledCircle]", 
      OverscriptBox["r", "\[RightVector]"]}], "||"}]], TraditionalForm]]],
 " como:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"torsion", 
   StyleBox["[",
    FontWeight->"Bold"], 
   StyleBox[
    RowBox[{"r_", ",", "t_"}],
    FontWeight->"Bold"], 
   StyleBox["]",
    FontWeight->"Bold"]}], 
  StyleBox[":=",
   FontWeight->"Bold"], 
  StyleBox[
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V", ",", "T"}], "}"}], ",", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{"V", "[", "t", "]"}], "=", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"r", "[", "t", "]"}], ",", "t"}], "]"}]}], ";", "\n", "    ", 
      RowBox[{"T", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{
           RowBox[{"V", "[", "t", "]"}], ",", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"V", "[", "t", "]"}], ",", "t"}], "]"}]}], "]"}], ".", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"V", "[", "t", "]"}], ",", "t"}], "]"}]}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"Cross", "[", 
           RowBox[{
            RowBox[{"r", "[", "t", "]"}], ",", 
            RowBox[{"V", "[", "t", "]"}]}], "]"}], ".", 
          RowBox[{"Cross", "[", 
           RowBox[{
            RowBox[{"r", "[", "t", "]"}], ",", 
            RowBox[{"V", "[", "t", "]"}]}], "]"}]}], "]"}]}]}], ";", "\n", 
      "    ", 
      RowBox[{"Return", "[", "T", "]"}]}]}], "]"}],
   FontWeight->"Bold"]}]], "Input",
 CellLabel->"In[61]:="],

Cell["\<\
de manera que la torsi\[OAcute]n de la h\[EAcute]lice el\[IAcute]ptica es:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"torsion", "[", 
   RowBox[{"h", ",", "t"}], "]"}], "]"}]], "Input",
 CellLabel->"In[62]:="],

Cell["\<\
Se deja al alumno el hacer una representaci\[OAcute]n gr\[AAcute]fica \
coloreada, y otra de grosor, de la h\[EAcute]lice el\[IAcute]ptica de acuerdo \
con la torsi\[OAcute]n.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Realice una representaci\[OAcute]n gr\[AAcute]fica coloreada,y otra de \
grosor, de la curva de Vidiani \n\n",
 StyleBox["x(t)=(1+cos(t)), y(t)=sin(t), z(t)=2sin(t/2), 0\[LessEqual]t\
\[LessEqual]4\[Pi]\n",
  FontSlant->"Italic"],
 "\nde acuerdo con la curvatura y la torsi\[OAcute]n. Realice tambi\[EAcute]n \
un gr\[AAcute]fico superpuesto con el triedro de Frenet (utilice s\[OAcute]lo \
el vector tangente y el normal)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Velocidad y aceleraci\[OAcute]n", "Subsubsection",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[TextData[{
 "Si una part\[IAcute]cula se mueve de manera que, en el instante ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", su posici\[OAcute]n viene dada por ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      OverscriptBox["r", "\[RightVector]"], "(", "t", ")"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "(", "t", ")"}], ",", 
       RowBox[{"y", "(", "t", ")"}], ",", 
       RowBox[{"z", "(", "t", ")"}]}], "}"}]}], ","}], TraditionalForm]]],
 " entonces su velocidad viene dada por ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["v", "\[RightVector]"], "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       OverscriptBox["r", "\[RightVector]"], "'"}], 
      RowBox[{"(", "t", ")"}]}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], 
         RowBox[{"(", "t", ")"}]}], ",", 
        RowBox[{
         RowBox[{"y", "'"}], 
         RowBox[{"(", "t", ")"}]}], ",", 
        RowBox[{
         RowBox[{"z", "'"}], 
         RowBox[{"(", "t", ")"}]}]}], "}"}], "."}]}]}], TraditionalForm]]],
 " La velocidad es tangente a la trayectoria en todos los puntos (donde no se \
anula). Por ejemplo, dada la siguiente trayectoria:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"r", ",", "t"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r", "[", "t_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], ",", 
     RowBox[{"t", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", "t"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"remolino", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"t", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], ",", 
      RowBox[{"t", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], ",", "t"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"6", "Pi"}]}], "}"}], ",", 
    RowBox[{"ViewPoint", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.258"}], ",", " ", "3.293", ",", " ", "0.875"}], 
      "}"}]}]}], "]"}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[63]:="],

Cell["La velocidad se calcula como:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "v", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"v", "[", "t_", "]"}], ":=", 
  RowBox[{
   SuperscriptBox["r", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"v", "[", "t", "]"}], "]"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[66]:="],

Cell["\<\
Representemos gr\[AAcute]ficamente la velocidad en 40  puntos de la \
trayectoria anterior\
\>", "Text"],

Cell[BoxData[{
 StyleBox[
  RowBox[{"<<", "Graphics`PlotField3D`"}],
  FontWeight->"Bold"], "\[IndentingNewLine]", 
 RowBox[{"velolistplot", "=", 
  RowBox[{"ListPlotVectorField3D", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r", "[", "i", "]"}], ",", 
        RowBox[{"v", "[", "i", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", 
        RowBox[{"6", "Pi"}], ",", 
        RowBox[{"6", 
         RowBox[{"Pi", "/", "40"}]}]}], "}"}]}], "]"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"ViewPoint", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.258"}], ",", " ", "3.293", ",", " ", "0.875"}], 
      "}"}]}], ",", 
    RowBox[{"VectorHeads", "\[Rule]", "True"}]}], "]"}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[69]:="],

Cell["\<\
De la misma forma, la aceleraci\[OAcute]n viene dada por:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "[", "t_", "]"}], ":=", 
  RowBox[{
   SuperscriptBox["v", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a", "[", "t", "]"}], "]"}]}], "Input",
 CellLabel->"In[71]:="],

Cell["\<\
Representemos gr\[AAcute]ficamente la aceleraci\[OAcute]n en 40  puntos de la \
trayectoria anterior\
\>", "Text"],

Cell[BoxData[
 RowBox[{"acelistplot", "=", 
  RowBox[{"ListPlotVectorField3D", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r", "[", "i", "]"}], ",", 
        RowBox[{"a", "[", "i", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", 
        RowBox[{"6", "Pi"}], ",", 
        RowBox[{"6", 
         RowBox[{"Pi", "/", "15"}]}]}], "}"}]}], "]"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"ViewPoint", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.258"}], ",", " ", "3.293", ",", " ", "0.875"}], 
      "}"}]}], ",", 
    RowBox[{"VectorHeads", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellLabel->"In[73]:="],

Cell["o desde otro punto de vista (visto desde arriba):", "Text"],

Cell[BoxData[
 RowBox[{"ListPlotVectorField3D", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", "[", "i", "]"}], ",", 
       RowBox[{"a", "[", "i", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"6", "Pi"}], ",", 
       RowBox[{"6", 
        RowBox[{"Pi", "/", "10"}]}]}], "}"}]}], "]"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ViewPoint", "->", 
    RowBox[{"{", 
     RowBox[{"0.033", ",", " ", "0.069", ",", " ", "5.763"}], "}"}]}], ",", 
   RowBox[{"VectorHeads", "\[Rule]", "True"}]}], "]"}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[74]:="],

Cell["\<\
que indica que la aceleraci\[OAcute]n apunta hacia adentro de la trayectoria \
y aumenta conforme nos elevamos en altura.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Haga una representaci\[OAcute]n gr\[AAcute]fica de la velocidad y aceleraci\
\[OAcute]n de un planeta en su movimiento alrededor de una estrella  \
siguiendo una trayectoria el\[IAcute]ptica de semiejes 4 y 1\n\n",
 StyleBox["x(t)=4cos(t), y(t)=sen(t)\n\n",
  FontSlant->"Italic"],
 "en los 8 puntos siguientes t=0, \[Pi]/4, 2\[Pi]/4, 3\[Pi]/4, \[Pi], \
5\[Pi]/4, 6\[Pi]/4 y 7\[Pi]/4"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Componentes tangencial y normal de la aceleraci\[OAcute]n\
\>", "Subsubsection",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[TextData[{
 "Las componentes intr\[IAcute]nsecas de la aceleraci\[OAcute]n \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["a", "\[RightVector]"], "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["a", "t"], "(", "t", ")"}], 
      OverscriptBox["v", "^"]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "n"], "(", "t", ")"}], " ", 
      OverscriptBox["n", "^"]}]}]}], TraditionalForm]]],
 "\n\nson \n\ncomponente tangencial:  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "t"], "="}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"d", " ", "v"}], 
    RowBox[{"d", " ", "t"}]], TraditionalForm]]],
 ",   \ncomponente normal:      ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{
     SuperscriptBox["v", "2"], "\[Kappa]"}]}], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["v", "2"], "/", "R"}], TraditionalForm]]],
 "\n\ndonde ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["v", "\[RightVector]"], "=", 
    RowBox[{"v", 
     OverscriptBox["v", "^"]}]}], TraditionalForm]]],
 " es la velocidad (m\[OAcute]dulo por vector unitario), \[Kappa] es la \
curvatura y ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["n", "^"], TraditionalForm]]],
 " el vector normal. Veamos c\[OAcute]mo calcular y representar dichas \
componentes. Tomemos como ejemplo la elipse de semiejes 3 y 1:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"r", ",", "t"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"r", "[", "t_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"3", " ", 
     RowBox[{"Cos", "[", "t", "]"}]}], ",", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], "}"}]}], "\n", 
 RowBox[{
  RowBox[{"elip", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], ",", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"Dashing", "[", 
       RowBox[{"{", "0.02", "}"}], "]"}]}], ",", 
     RowBox[{"Axes", "->", "False"}]}], "]"}]}], ";"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[75]:="],

Cell["\<\
La velocidad, su m\[OAcute]dulo y su direcci\[OAcute]n y el vector normal \
unitario son:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"v", "[", "t_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], ";", " ", 
  RowBox[{"v", "[", "t", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"vmod", "[", "t_", "]"}], ":=", 
   SqrtBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["r", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], ".", 
     RowBox[{
      SuperscriptBox["r", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]]}], ";", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"vmod", "[", "t", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"vu", "[", "t_", "]"}], ":=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["r", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], 
    SqrtBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], ".", 
      RowBox[{
       SuperscriptBox["r", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]]]}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{"vu", "[", "t", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nu", "[", "t_", "]"}], ":=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["vu", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], 
    SqrtBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["vu", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], ".", 
      RowBox[{
       SuperscriptBox["vu", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]]]}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{"nu", "[", "t", "]"}], "]"}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[78]:="],

Cell["La aceleraci\[OAcute]n es:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "a", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "t_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "\[DoublePrime]",
     MultilineFunction->None], "[", "t", "]"}]}], ";", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"a", "[", "t", "]"}], "]"}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[82]:="],

Cell["\<\
Las componentes tangencial y normal se obtienen proyectando sobre los \
vectores unitarios tangencial y normal:\
\>", "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"at", ",", "an"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"at", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], ".", 
     RowBox[{"vu", "[", "t", "]"}]}], ")"}], 
   RowBox[{"vu", "[", "t", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"an", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], ".", 
     RowBox[{"nu", "[", "t", "]"}]}], ")"}], 
   RowBox[{"nu", "[", "t", "]"}]}]}]}], "Input",
 CellLabel->"In[84]:="],

Cell[TextData[{
 "El radio de curvatura es ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", "=", 
    RowBox[{
     SuperscriptBox["v", "2"], "/", 
     SubscriptBox["a", "n"]}]}], TraditionalForm]]],
 ", ",
 "o sea",
 ":"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"rcurv", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"vmod", "[", "t", "]"}], "^", "2"}], "/", 
    SqrtBox[
     RowBox[{
      RowBox[{"an", "[", "t", "]"}], ".", 
      RowBox[{"an", "[", "t", "]"}]}]]}]}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{"rcurv", "[", "t", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"rcurv", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "Pi"}]}], "}"}]}], "]"}]}], "Input",
 CellLabel->"In[87]:="],

Cell["\<\
que presenta m\[AAcute]ximos en t=\[Pi]/2 y t=3\[Pi]/2.  Representemos la \
aceleraci\[OAcute]n tangencial y normal en gr\[AAcute]ficos superpuestos:\
\>", "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 StyleBox[
  RowBox[{"<<", "Graphics`PlotField`"}],
  FontWeight->"Bold"], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"atlistplot", "=", 
   RowBox[{"ListPlotVectorField", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r", "[", "i", "]"}], ",", 
         RowBox[{"at", "[", "i", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", 
         RowBox[{"2", "Pi"}], ",", 
         RowBox[{"2", 
          RowBox[{"Pi", "/", "16"}]}]}], "}"}]}], "]"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellLabel->"In[89]:="],

Cell[BoxData[{
 StyleBox[
  RowBox[{"<<", "Graphics`PlotField`"}],
  FontWeight->"Bold"], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"anlistplot", "=", 
   RowBox[{"ListPlotVectorField", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r", "[", "i", "]"}], ",", 
         RowBox[{"an", "[", "i", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", 
         RowBox[{"2", "Pi"}], ",", 
         RowBox[{"2", 
          RowBox[{"Pi", "/", "16"}]}]}], "}"}]}], "]"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellLabel->"In[91]:="],

Cell["\<\
Superpongamos los gr\[AAcute]ficos de la  elipse y las componentes tangencial \
y normal de la aceleraci\[OAcute]n:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"elip", ",", "atlistplot", ",", "anlistplot"}], "]"}]], "Input",
 CellLabel->"In[93]:="],

Cell["\<\
Observamos que la aceleraci\[OAcute]n tangencial es nula en \
t=0,\[Pi]/2,\[Pi], y 3\[Pi]/2. Hagamos una representaci\[OAcute]n \
gr\[AAcute]fica conjunta de los m\[OAcute]dulos de la aceleraci\[OAcute]n y \
de sus componentes intr\[IAcute]nsecas \
\>", "Text"],

Cell[BoxData[{
 RowBox[{"<<", "Graphics`Legend`"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], ".", 
       RowBox[{"a", "[", "t", "]"}]}]], ",", 
     SqrtBox[
      RowBox[{
       RowBox[{"at", "[", "t", "]"}], ".", 
       RowBox[{"at", "[", "t", "]"}]}]], ",", 
     SqrtBox[
      RowBox[{
       RowBox[{"an", "[", "t", "]"}], ".", 
       RowBox[{"an", "[", "t", "]"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
      RowBox[{"Dashing", "[", 
       RowBox[{"{", ".01", "}"}], "]"}], ",", 
      RowBox[{"Dashing", "[", 
       RowBox[{"{", ".03", "}"}], "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotLegend", "->", 
    RowBox[{"{", 
     RowBox[{
     "\"\<a(t)\>\"", ",", "\"\<\!\(\*SubscriptBox[\(a\), \(t\)]\)(t)\>\"", 
      ",", "\"\<\!\(\*SubscriptBox[\(a\), \(n\)]\)(t)\>\""}], "}"}]}], ",", 
   RowBox[{"LegendPosition", "->", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "0.4"}]}], "}"}]}]}], "]"}]}], "Input",
 CellLabel->"In[94]:="],

Cell["\<\
Vemos que la aceleraci\[OAcute]n total nunca es nula.  Tambi\[EAcute]n vemos \
que, cuando la aceleraci\[OAcute]n normal es m\[AAcute]xima, la aceleraci\
\[OAcute]n tangencial es m\[IAcute]nima y viceversa.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Calcular las componentes intr\[IAcute]nsecas de la aceleraci\[OAcute]n para \
una part\[IAcute]cula movi\[EAcute]ndose a lo largo de una hip\[EAcute]rbola \
equil\[AAcute]tera ",
 StyleBox["y=1/x  ",
  FontSlant->"Italic"],
 "con ",
 StyleBox["x(t)=",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["t", "2"], "+", "1"}], TraditionalForm]]],
 StyleBox[", y(t)=1/",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["t", "2"], "+", "1"}], ")"}], TraditionalForm]]],
 StyleBox[" ",
  FontSlant->"Italic"],
 "en el intervalo",
 StyleBox[" -0.5\[LessEqual]t\[LessEqual]0.5. ",
  FontSlant->"Italic"],
 "Representar gr\[AAcute]ficamente el radio de curvatura, las componentes \
intr\[IAcute]nsecas de la aceleraci\[OAcute]n y sus m\[OAcute]dulos en funci\
\[OAcute]n del tiempo tal y como se hace en el texto."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Geometr\[IAcute]a de superficies", "Subsection",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[CellGroupData[{

Cell["\<\
Superficies parametrizadas: plano tangente y \[AAcute]rea\
\>", "Subsubsection"],

Cell["\<\
Para una curva, la recta tangente en un punto juega un papel fundamental como \
aproximaci\[OAcute]n lineal de la curva en dicho punto. Para una superficie \
es el plano tangente en un punto quien juega este papel. Consideremos por \
ejemplo la esfera de radio 1 parametrizada en coordenadas esf\[EAcute]ricas:\
\>", "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"r", ",", "u", ",", "v"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "u", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], ",", 
    RowBox[{
     RowBox[{"Sin", "[", "u", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], ",", 
    RowBox[{"Cos", "[", "v", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"esfera", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], ",", " ", 
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], ",", " ", 
       RowBox[{"Cos", "[", "v", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "0", ",", "\[Pi]"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[96]:="],

Cell[TextData[{
 "Para encontrar el plano tangente a la esfera en el punto ",
 StyleBox["(u,v)=(\[Pi]/4,\[Pi]/4)->",
  FontSlant->"Italic"],
 " ",
 StyleBox["(x,y,z)=(1/2,1/2,1/",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SqrtBox["2"],
    FontSlant->"Italic"], TraditionalForm]]],
 StyleBox[") ",
  FontSlant->"Italic"],
 "podemos empezar por calcular el vector normal a la esfera en un punto ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["n", "\[RightVector]"], "=", 
    RowBox[{
     SubscriptBox["\[PartialD]", "u"], 
     RowBox[{
      RowBox[{
       OverscriptBox["r", "\[RightVector]"], "(", 
       RowBox[{"u", ",", "v"}], ")"}], "\[Cross]", 
      RowBox[{
       SubscriptBox["\[PartialD]", "v"], 
       RowBox[{
        OverscriptBox["r", "\[RightVector]"], "(", 
        RowBox[{"u", ",", "v"}], ")"}]}]}]}]}], TraditionalForm]]],
 " (producto vectorial de los vectores tangentes a los paralelos  ",
 StyleBox["v=cte",
  FontSlant->"Italic"],
 ", y a los meridianos ",
 StyleBox["u=cte",
  FontSlant->"Italic"],
 ", respectivamente) y particularizarlo a ",
 StyleBox["(u,v)=(\[Pi]/4,\[Pi]/4)",
  FontSlant->"Italic"],
 ", ",
 "como:"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "vn", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vn", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "u"], 
     RowBox[{"r", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "\[Cross]", 
    RowBox[{
     SubscriptBox["\[PartialD]", "v"], 
     RowBox[{"r", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", "vn", "]"}], "\[IndentingNewLine]", 
 RowBox[{"vn0", "=", 
  RowBox[{"vn", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "->", 
      RowBox[{"Pi", "/", "4"}]}], ",", 
     RowBox[{"v", "->", 
      RowBox[{"Pi", "/", "4"}]}]}], "}"}]}]}]}], "Input",
 CellLabel->"In[99]:="],

Cell[TextData[{
 "La ecuaci\[OAcute]n del plano tangente a la superficie en un punto ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["r", "\[RightVector]"], "0"], TraditionalForm]]],
 " vendr\[AAcute] dada entonces por ( ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      FormBox[
       RowBox[{
        OverscriptBox["r", "\[RightVector]"], "-"}],
       TraditionalForm], 
      FormBox[
       SubscriptBox[
        OverscriptBox["r", "\[RightVector]"], "0"],
       TraditionalForm]}], ")"}], "\[FilledCircle]", 
    SubscriptBox[
     FormBox[
      OverscriptBox["n", "\[RightVector]"],
      TraditionalForm], "0"]}], TraditionalForm]]],
 " =0. Dibuj\[EAcute]moslo:"
}], "Text"],

Cell[BoxData[{
 RowBox[{"<<", "Graphics`ContourPlot3D`"}], "\[IndentingNewLine]", 
 RowBox[{"ptesfera", "=", 
  RowBox[{"ContourPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "-", 
       RowBox[{"r", "[", 
        RowBox[{
         FractionBox["\[Pi]", "4"], ",", 
         FractionBox["\[Pi]", "4"]}], "]"}]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{"vn", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"u", "\[Rule]", 
          FractionBox["\[Pi]", "4"]}], ",", 
         RowBox[{"v", "\[Rule]", 
          FractionBox["\[Pi]", "4"]}]}], "}"}]}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[103]:="],

Cell["\<\
y utilizando gr\[AAcute]ficos superpuestos:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"esfera", ",", "ptesfera"}], "]"}]], "Input",
 CellLabel->"In[105]:="],

Cell[TextData[{
 "En vez de representar el plano tangente como una curva de nivel de \n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "(", 
     RowBox[{"x", ",", "y", ",", "z"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["n", "1"], "(", 
       RowBox[{"x", "-", 
        SubscriptBox["x", "0"]}], ")"}], "+", 
      RowBox[{
       SubscriptBox["n", "2"], "(", 
       RowBox[{"y", "-", 
        SubscriptBox["y", "0"]}], ")"}], "+", 
      RowBox[{
       SubscriptBox["n", "3"], "(", 
       RowBox[{"z", "-", 
        SubscriptBox["z", "0"]}], ")"}]}], "=", "0"}]}], TraditionalForm]]],
 " usando ",
 StyleBox["ContourPlot3D, ",
  FontWeight->"Bold"],
 "otra opci\[OAcute]n es despejar ",
 "\n ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", 
    RowBox[{
     RowBox[{"[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["n", "1"], "(", 
         RowBox[{"x", "-", 
          SubscriptBox["x", "0"]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["n", "0"], "(", 
        RowBox[{"y", "-", 
         SubscriptBox["y", "0"]}], ")"}], "+", 
       RowBox[{
        SubscriptBox["n", "3"], 
        SubscriptBox["z", "0"]}]}], "]"}], "/", 
     SubscriptBox["n", "3"]}]}], TraditionalForm]]],
 " y usar  ",
 StyleBox["Plot3D",
  FontWeight->"Bold"]
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 TextAlignment->Left,
 TextJustification->1,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{"n1", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"vn", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "\[Rule]", 
        FractionBox["\[Pi]", "4"]}], ",", 
       RowBox[{"v", "\[Rule]", 
        FractionBox["\[Pi]", "4"]}]}], "}"}]}], ")"}], "\[LeftDoubleBracket]",
    "1", "\[RightDoubleBracket]"}]}], "\n", 
 RowBox[{"n2", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"vn", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "\[Rule]", 
        FractionBox["\[Pi]", "4"]}], ",", 
       RowBox[{"v", "\[Rule]", 
        FractionBox["\[Pi]", "4"]}]}], "}"}]}], ")"}], "\[LeftDoubleBracket]",
    "2", "\[RightDoubleBracket]"}]}], "\n", 
 RowBox[{"n3", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"vn", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "\[Rule]", 
        FractionBox["\[Pi]", "4"]}], ",", 
       RowBox[{"v", "\[Rule]", 
        FractionBox["\[Pi]", "4"]}]}], "}"}]}], ")"}], "\[LeftDoubleBracket]",
    "3", "\[RightDoubleBracket]"}]}], "\n", 
 RowBox[{"x0", "=", 
  RowBox[{
   RowBox[{"r", "[", 
    RowBox[{
     FractionBox["\[Pi]", "4"], ",", 
     FractionBox["\[Pi]", "4"]}], "]"}], "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\n", 
 RowBox[{"y0", "=", 
  RowBox[{
   RowBox[{"r", "[", 
    RowBox[{
     FractionBox["\[Pi]", "4"], ",", 
     FractionBox["\[Pi]", "4"]}], "]"}], "\[LeftDoubleBracket]", "2", 
   "\[RightDoubleBracket]"}]}], "\n", 
 RowBox[{"z0", "=", 
  RowBox[{
   RowBox[{"r", "[", 
    RowBox[{
     FractionBox["\[Pi]", "4"], ",", 
     FractionBox["\[Pi]", "4"]}], "]"}], "\[LeftDoubleBracket]", "3", 
   "\[RightDoubleBracket]"}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[106]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptesfera2", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "n1"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "x0"}], ")"}]}], "-", 
       RowBox[{"n2", " ", 
        RowBox[{"(", 
         RowBox[{"y", "-", "y0"}], ")"}]}], "+", 
       RowBox[{"n3", " ", "z0"}]}], "n3"], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[112]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"esfera", ",", "ptesfera2"}], "]"}], ";"}]], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[113]:="],

Cell[TextData[{
 "Podemos calcular la superficie de la esfera mediante la integral ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", 
         RowBox[{"2", "\[Pi]"}]], 
        FormBox[
         RowBox[{"||", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[PartialD]", "u"], 
            RowBox[{
             OverscriptBox["r", "\[RightVector]"], "(", 
             RowBox[{"u", ",", "v"}], ")"}]}], "\[Cross]", 
           RowBox[{
            SubscriptBox["\[PartialD]", "v"], 
            RowBox[{
             OverscriptBox["r", "\[RightVector]"], "(", 
             RowBox[{"u", ",", "v"}], ")"}]}]}]}],
         TraditionalForm]}], "||", 
       RowBox[{"\[DifferentialD]", "u"}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "v"}]}]}], TraditionalForm]]],
 " donde ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     RowBox[{"||", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "u"], 
        RowBox[{
         OverscriptBox["r", "\[RightVector]"], "(", 
         RowBox[{"u", ",", "v"}], ")"}]}], "\[Cross]", 
       RowBox[{
        SubscriptBox["\[PartialD]", "v"], 
        RowBox[{
         OverscriptBox["r", "\[RightVector]"], "(", 
         RowBox[{"u", ",", "v"}], ")"}]}]}]}],
     TraditionalForm], "||"}], TraditionalForm]]],
 "=||",
 Cell[BoxData[
  FormBox[
   OverscriptBox["n", "\[RightVector]"], TraditionalForm]]],
 "|| es el m\[OAcute]dulo del vector normal. En efecto, la integral:"
}], "Text"],

Cell[BoxData[
 RowBox[{" ", 
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{
        SqrtBox[
         RowBox[{
          FormBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[PartialD]", "u"], 
              RowBox[{"r", "(", 
               RowBox[{"u", ",", "v"}], ")"}]}], "\[Cross]", 
             RowBox[{
              SubscriptBox["\[PartialD]", "v"], 
              RowBox[{"r", "(", 
               RowBox[{"u", ",", "v"}], ")"}]}]}], ")"}],
           TraditionalForm], ".", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[PartialD]", "u"], 
             RowBox[{"r", "(", 
              RowBox[{"u", ",", "v"}], ")"}]}], "\[Cross]", 
            RowBox[{
             SubscriptBox["\[PartialD]", "v"], 
             RowBox[{"r", "(", 
              RowBox[{"u", ",", "v"}], ")"}]}]}], ")"}]}]], 
        RowBox[{"\[DifferentialD]", "u"}]}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "v"}]}]}],
   TraditionalForm]}]], "Input",
 CellLabel->"In[114]:="],

Cell["nos da la superficie de la esfera de radio 1.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Superficies en forma impl\[IAcute]cita y \[AAcute]rea\
\>", "Subsubsection"],

Cell[TextData[{
 "Para superficies dadas de forma impl\[IAcute]cita ",
 StyleBox["F(x,y,z)=0 ",
  FontSlant->"Italic"],
 "(consideraremos la forma expl\[IAcute]cita ",
 StyleBox["z=S(x,y)",
  FontSlant->"Italic"],
 " como un caso particular de forma impl\[IAcute]cita ",
 StyleBox["F(x,y,z)=S(x,y)-z=0)",
  FontSlant->"Italic"],
 " ",
 StyleBox[",",
  FontSlant->"Italic"],
 " recuerde que el vector gradiente  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["n", "\[RightVector]"], "=", 
    RowBox[{
     RowBox[{"\[Del]", "F"}], "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", "F"}], ",", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", "F"}], ",", 
       RowBox[{
        SubscriptBox["\[PartialD]", "z"], " ", "F"}]}], ")"}]}]}], 
   TraditionalForm]]],
 " es normal a la superficie ",
 StyleBox["F(x,y,z)=0",
  FontSlant->"Italic"],
 " en cada punto. \n\nN\[OAcute]tese que, como un caso particular de \
parametrizaci\[OAcute]n ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["r", "\[RightVector]"], "(", 
    RowBox[{"u", ",", "v"}], ")"}], TraditionalForm]]],
 ", siempre podemos tomar:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "u"}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "v"}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", 
    RowBox[{"S", "(", 
     RowBox[{"u", ",", "v"}], ")"}]}], TraditionalForm]]],
 "\n\nentonces se tiene que los vectores tangentes a la superficie en las \
direcciones  ",
 StyleBox["x=cte=z ",
  FontSlant->"Italic"],
 " e  ",
 " ",
 StyleBox["y=cte=z ",
  FontSlant->"Italic"],
 "son:",
 "\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "u"], 
     OverscriptBox["r", "\[RightVector]"]}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], 
      OverscriptBox["r", "\[RightVector]"]}], "=", 
     RowBox[{"(", 
      RowBox[{"1", ",", "0", ",", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], "S"}]}], ")"}]}]}], 
   TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "v"], 
     OverscriptBox["r", "\[RightVector]"]}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], 
      OverscriptBox["r", "\[RightVector]"]}], "=", 
     RowBox[{"(", 
      RowBox[{"0", ",", "1", ",", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "S"}]}], ")"}]}]}], 
   TraditionalForm]]],
 "\n\nde donde se obtiene el vector normal a la superficie:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "u"], 
      OverscriptBox["r", "\[RightVector]"]}], "\[Times]", 
     RowBox[{
      SubscriptBox["\[PartialD]", "v"], 
      OverscriptBox["r", "\[RightVector]"]}]}], "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], "S"}]}], ",", 
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "S"}]}], ",", "1"}], ")"}]}], 
   TraditionalForm]]],
 "\n\nque coincide con ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Del]", "F"}], "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", "F"}], ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", "F"}], ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "z"], " ", "F"}]}], ")"}]}], 
   TraditionalForm]]],
 " cuando ",
 StyleBox["F(x,y,z)=S(x,y)-z. \n\n",
  FontSlant->"Italic"],
 "Tomemos como ejemplo un paraboloide:"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"S", ",", "F", ",", "x", ",", "y"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"S", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"1", "-", 
   SuperscriptBox["x", "2"], "-", 
   SuperscriptBox["y", "2"]}]}], "\n", 
 RowBox[{
  RowBox[{"F", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"S", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "-", "z"}]}], "\[IndentingNewLine]", 
 RowBox[{"paraboloide", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"S", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[115]:="],

Cell[TextData[{
 "El vector normal a",
 StyleBox[" S",
  FontSlant->"Italic"],
 " en un punto arbitrario",
 StyleBox[" (x,y,z) ",
  FontSlant->"Italic"],
 "es:"
}], "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "vn", "]"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Calculus`VectorAnalysis`"}], "\[IndentingNewLine]", 
 RowBox[{"vn", "=", 
  RowBox[{"Grad", "[", 
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
    RowBox[{"Cartesian", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}], "Input",
 ShowGroupOpener->True,
 AspectRatioFixed->True,
 FontFamily->"New York",
 CellLabel->"In[119]:="],

Cell[TextData[{
 "El plano tangente al paraboloide en el punto",
 StyleBox[" (x,y,z)=(1/2,1/2,1/2) ",
  FontSlant->"Italic"],
 "se representa como:"
}], "Text"],

Cell[BoxData[{
 RowBox[{"<<", "Graphics`ContourPlot3D`"}], "\[IndentingNewLine]", 
 RowBox[{"ptparaboloide", "=", 
  RowBox[{"ContourPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "-", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", 
         RowBox[{"1", "/", "2"}], ",", 
         RowBox[{"1", "/", "2"}]}], "}"}]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{"vn", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "\[Rule]", 
          FractionBox["1", "2"]}], ",", 
         RowBox[{"y", "\[Rule]", 
          FractionBox["1", "2"]}], ",", 
         RowBox[{"z", "\[Rule]", 
          FractionBox["1", "2"]}]}], "}"}]}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}], "Input",
 CellLabel->"In[122]:="],

Cell["Que superpuesto al paraboloide queda:", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"paraboloide", ",", "ptparaboloide"}], "]"}]], "Input",
 CellLabel->"In[124]:="],

Cell[TextData[{
 "El \[AAcute]rea de la porci\[OAcute]n de paraboloide por encima del \
cuadrado [-0.5,0.5]\[Times][-0.5,0.5] se puede calcular como ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "0.5"}], "0.5"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "0.5"}], "0.5"], 
       RowBox[{
        FractionBox["1", 
         RowBox[{"|", 
          RowBox[{
           OverscriptBox["n", "^"], "\[FilledCircle]", 
           OverscriptBox["k", "^"]}], "|"}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "y"}]}]}], TraditionalForm]]],
 ". M\[AAcute]s expl\[IAcute]citamente:"
}], "Text"],

Cell[BoxData[
 RowBox[{"Abs", "[", 
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "0.5"}], "0.5"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "0.5"}], "0.5"], 
      RowBox[{
       FractionBox["1", 
        FractionBox[
         RowBox[{"vn", ".", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], 
         SqrtBox[
          RowBox[{"vn", ".", "vn"}]]]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}], ")"}], 
    RowBox[{"\[DifferentialD]", "y"}]}]}], "]"}]], "Input",
 CellLabel->"In[125]:="],

Cell[TextData[{
 "donde se ha tomado el valor absoluto debido a que la proyecci\[OAcute]n ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["n", "^"], "\[FilledCircle]", 
    OverscriptBox["k", "^"]}], TraditionalForm]]],
 " del  vector normal calculado {-2 x,-2 y,-1} sobre el eje z es negativa."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Hallar el plano tangente y el \[AAcute]rea de las siguientes superficies en \
el punto que se indica:\n\na) Superficie generada al revolucionar la curva:  ",
 StyleBox["y=",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"sen", "(", "x", ")"}], TraditionalForm]]],
 ", 0\[LessEqual]",
 StyleBox["x",
  FontSlant->"Italic"],
 "<\[Pi], en torno al eje X. Punto x=\[Pi]/2.\n\nb) Silla de montar: z=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["y", "2"], "-"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 ", ",
 StyleBox["-1\[LessEqual]x\[LessEqual]1",
  FontSlant->"Italic"],
 ", ",
 StyleBox["-1\[LessEqual]y\[LessEqual]1. ",
  FontSlant->"Italic"],
 " Punto (x,y,)=(1/2,1/2,0)."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingStartingPageNumber->81,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      OptionValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      OptionValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"FacingPages"->True,
"FirstPageHeader"->False,
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{72, 72}, {57.5625, 57.5625}}},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Textbook.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 163, 6, 82, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[755, 32, 177, 6, 37, "Subsection",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[957, 42, 46, 0, 35, "Subsubsection"],
Cell[1006, 44, 1258, 43, 41, "Text",
 Evaluatable->False],
Cell[2267, 89, 556, 18, 85, "Input"],
Cell[2826, 109, 182, 3, 23, "Text"],
Cell[3011, 114, 472, 15, 27, "Input"],
Cell[3486, 131, 376, 9, 39, "Text",
 Evaluatable->False],
Cell[3865, 142, 879, 26, 86, "Input"],
Cell[4747, 170, 462, 13, 39, "Text",
 Evaluatable->False],
Cell[5212, 185, 1180, 40, 114, "Input"],
Cell[6395, 227, 213, 7, 25, "Text",
 Evaluatable->False],
Cell[6611, 236, 3234, 111, 266, "Text",
 Evaluatable->False],
Cell[9848, 349, 505, 18, 43, "Input"],
Cell[10356, 369, 631, 23, 25, "Text"],
Cell[10990, 394, 649, 20, 72, "Input"],
Cell[11642, 416, 725, 22, 59, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12404, 443, 35, 0, 37, "Subsubsection"],
Cell[12442, 445, 1209, 31, 467, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13688, 481, 203, 7, 37, "Subsubsection",
 Evaluatable->False],
Cell[13894, 490, 966, 34, 43, "Text",
 Evaluatable->False],
Cell[14863, 526, 647, 20, 85, "Input"],
Cell[15513, 548, 166, 4, 25, "Text",
 Evaluatable->False],
Cell[15682, 554, 764, 25, 80, "Input"],
Cell[16449, 581, 194, 8, 25, "Text"],
Cell[16646, 591, 300, 10, 29, "Input"],
Cell[16949, 603, 321, 12, 25, "Text",
 Evaluatable->False],
Cell[17273, 617, 394, 13, 48, "Input"],
Cell[17670, 632, 1282, 50, 42, "Text",
 Evaluatable->False],
Cell[18955, 684, 326, 10, 48, "Input"],
Cell[19284, 696, 253, 8, 25, "Text"],
Cell[19540, 706, 348, 12, 67, "Input"],
Cell[19891, 720, 355, 7, 42, "Text"],
Cell[20249, 729, 340, 11, 29, "Input"],
Cell[20592, 742, 354, 13, 25, "Text",
 Evaluatable->False],
Cell[20949, 757, 290, 10, 29, "Input"],
Cell[21242, 769, 279, 12, 25, "Text",
 Evaluatable->False],
Cell[21524, 783, 103, 3, 30, "Input"],
Cell[21630, 788, 529, 17, 42, "Text"],
Cell[22162, 807, 211, 7, 29, "Input"],
Cell[22376, 816, 248, 8, 29, "Input"],
Cell[22627, 826, 385, 13, 38, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23049, 844, 34, 0, 37, "Subsubsection"],
Cell[23086, 846, 1039, 39, 42, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24162, 890, 98, 2, 37, "Subsubsection"],
Cell[24263, 894, 596, 21, 25, "Text",
 Evaluatable->False],
Cell[24862, 917, 877, 28, 105, "Input"],
Cell[25742, 947, 60, 0, 25, "Text"],
Cell[25805, 949, 601, 20, 70, "Input"],
Cell[26409, 971, 127, 3, 25, "Text"],
Cell[26539, 976, 681, 22, 48, "Input"],
Cell[27223, 1000, 58, 0, 25, "Text"],
Cell[27284, 1002, 530, 17, 70, "Input"],
Cell[27817, 1021, 125, 3, 25, "Text"],
Cell[27945, 1026, 506, 16, 30, "Input"],
Cell[28454, 1044, 69, 2, 25, "Text"],
Cell[28526, 1048, 433, 13, 29, "Input"],
Cell[28962, 1063, 3331, 107, 536, "Text",
 Evaluatable->False],
Cell[32296, 1172, 1498, 46, 90, "Input"],
Cell[33797, 1220, 76, 2, 25, "Text"],
Cell[33876, 1224, 219, 7, 29, "Input"],
Cell[34098, 1233, 430, 15, 35, "Text"],
Cell[34531, 1250, 359, 13, 41, "Input"],
Cell[34893, 1265, 590, 15, 92, "Text"],
Cell[35486, 1282, 1046, 32, 130, "Input"],
Cell[36535, 1316, 32, 0, 25, "Text"],
Cell[36570, 1318, 145, 4, 30, "Input"],
Cell[36718, 1324, 149, 5, 25, "Text"],
Cell[36870, 1331, 815, 28, 73, "Input"],
Cell[37688, 1361, 259, 7, 25, "Text"],
Cell[37950, 1370, 677, 23, 73, "Input"],
Cell[38630, 1395, 142, 3, 25, "Text"],
Cell[38775, 1400, 674, 21, 50, "Input"],
Cell[39452, 1423, 187, 4, 25, "Text"],
Cell[39642, 1429, 728, 24, 73, "Input"],
Cell[40373, 1455, 154, 3, 25, "Text"],
Cell[40530, 1460, 675, 21, 50, "Input"],
Cell[41208, 1483, 711, 20, 80, "Text"],
Cell[41922, 1505, 1478, 48, 90, "Input"],
Cell[43403, 1555, 98, 2, 25, "Text"],
Cell[43504, 1559, 143, 4, 30, "Input"],
Cell[43650, 1565, 199, 4, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43886, 1574, 34, 0, 37, "Subsubsection"],
Cell[43923, 1576, 454, 9, 125, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44414, 1590, 151, 4, 37, "Subsubsection",
 Evaluatable->False],
Cell[44568, 1596, 1377, 45, 42, "Text",
 Evaluatable->False],
Cell[45948, 1643, 1033, 34, 67, "Input"],
Cell[46984, 1679, 45, 0, 25, "Text"],
Cell[47032, 1681, 418, 13, 67, "Input"],
Cell[47453, 1696, 114, 3, 25, "Text"],
Cell[47570, 1701, 934, 28, 48, "Input"],
Cell[48507, 1731, 81, 2, 25, "Text"],
Cell[48591, 1735, 267, 8, 50, "Input"],
Cell[48861, 1745, 124, 3, 25, "Text"],
Cell[48988, 1750, 756, 22, 50, "Input"],
Cell[49747, 1774, 65, 0, 25, "Text"],
Cell[49815, 1776, 750, 22, 29, "Input"],
Cell[50568, 1800, 145, 3, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50750, 1808, 34, 0, 37, "Subsubsection"],
Cell[50787, 1810, 414, 8, 125, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51238, 1823, 185, 6, 37, "Subsubsection",
 Evaluatable->False],
Cell[51426, 1831, 1602, 56, 269, "Text",
 Evaluatable->False],
Cell[53031, 1889, 977, 30, 67, "Input"],
Cell[54011, 1921, 113, 3, 25, "Text"],
Cell[54127, 1926, 1802, 58, 139, "Input"],
Cell[55932, 1986, 42, 0, 25, "Text"],
Cell[55977, 1988, 447, 14, 48, "Input"],
Cell[56427, 2004, 230, 7, 25, "Text",
 Evaluatable->False],
Cell[56660, 2013, 610, 20, 70, "Input"],
Cell[57273, 2035, 230, 11, 25, "Text"],
Cell[57506, 2048, 585, 19, 56, "Input"],
Cell[58094, 2069, 268, 7, 25, "Text",
 Evaluatable->False],
Cell[58365, 2078, 677, 21, 50, "Input"],
Cell[59045, 2101, 677, 21, 50, "Input"],
Cell[59725, 2124, 139, 3, 25, "Text"],
Cell[59867, 2129, 135, 3, 30, "Input"],
Cell[60005, 2134, 271, 5, 25, "Text"],
Cell[60279, 2141, 1263, 38, 74, "Input"],
Cell[61545, 2181, 230, 4, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61812, 2190, 34, 0, 37, "Subsubsection"],
Cell[61849, 2192, 919, 28, 42, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62817, 2226, 149, 4, 43, "Subsection",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[62991, 2234, 90, 2, 37, "Subsubsection"],
Cell[63084, 2238, 429, 9, 42, "Text",
 Evaluatable->False],
Cell[63516, 2249, 1221, 38, 67, "Input"],
Cell[64740, 2289, 1200, 41, 43, "Text"],
Cell[65943, 2332, 728, 23, 90, "Input"],
Cell[66674, 2357, 725, 25, 25, "Text"],
Cell[67402, 2384, 1079, 34, 61, "Input"],
Cell[68484, 2420, 67, 2, 25, "Text"],
Cell[68554, 2424, 117, 3, 30, "Input"],
Cell[68674, 2429, 1484, 54, 74, "Text",
 Evaluatable->False],
Cell[70161, 2485, 1779, 58, 212, "Input"],
Cell[71943, 2545, 709, 24, 45, "Input"],
Cell[72655, 2571, 211, 7, 29, "Input"],
Cell[72869, 2580, 1621, 51, 26, "Text"],
Cell[74493, 2633, 1235, 38, 42, "Input"],
Cell[75731, 2673, 61, 0, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75829, 2678, 86, 2, 37, "Subsubsection"],
Cell[75918, 2682, 3746, 136, 512, "Text",
 Evaluatable->False],
Cell[79667, 2820, 898, 29, 86, "Input"],
Cell[80568, 2851, 172, 8, 25, "Text"],
Cell[80743, 2861, 475, 13, 67, "Input"],
Cell[81221, 2876, 160, 5, 25, "Text"],
Cell[81384, 2883, 1108, 34, 63, "Input"],
Cell[82495, 2919, 53, 0, 25, "Text"],
Cell[82551, 2921, 127, 3, 30, "Input"],
Cell[82681, 2926, 749, 22, 42, "Text"],
Cell[83433, 2950, 608, 20, 63, "Input"],
Cell[84044, 2972, 318, 8, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84399, 2985, 34, 0, 37, "Subsubsection"],
Cell[84436, 2987, 789, 26, 125, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

