(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     40178,       1392]
NotebookOptionsPosition[     35558,       1250]
NotebookOutlinePosition[     36619,       1289]
CellTagsIndexPosition[     36576,       1286]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Operadores vectoriales en coordenadas curvil\[IAcute]neas \
\>", "Section",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[CellGroupData[{

Cell["\<\
Coordenadas curvil\[IAcute]neas ortogonales. Factores de escala. Cambio de \
base\
\>", "Subsection"],

Cell[TextData[{
 "Cuando fijamos un sistema de referencia respecto al cual medir longitudes o \
\[AAcute]ngulos, tres n\[UAcute]meros bastan para identificar la posici\
\[OAcute]n de un punto en el espacio. Estos tres n\[UAcute]meros pueden \
escogerse de m\[UAcute]ltiples formas. Dependiendo de la geometr\[IAcute]a \
del problema, unos sistemas de coordenadas pueden resultar m\[AAcute]s \
\[UAcute]tiles que otros, en el sentido de que las ecuaciones implicadas \
admiten una forma m\[AAcute]s simple. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " tiene incorporados varios sistemas de coordenadas dentro del paquete \
<<Calculus`VectorAnalysis`, entre ellos: coordenadas cartesianas (Cartesian), \
esf\[EAcute]ricas (Spherical) y cil\[IAcute]ndricas (Cylindrical), que son \
los que nosotros utilizaremos mayormente."
}], "Text"],

Cell[BoxData[
 RowBox[{"Sistemas", " ", "de", " ", "coordenadas", " ", 
  RowBox[{"curvil\[IAcute]neas", ":", 
   StyleBox[
    FrameBox[
     StyleBox[GridBox[{
        {"\<\"Bipolar\"\>", "\<\"Bispherical\"\>"},
        {"\<\"Cartesian\"\>", "\<\"ConfocalEllipsoidal\"\>"},
        {"\<\"ConfocalParaboloidal\"\>", "\<\"Conical\"\>"},
        {"\<\"Cylindrical\"\>", "\<\"EllipticCylindrical\"\>"},
        {"\<\"OblateSpheroidal\"\>", "\<\"ParabolicCylindrical\"\>"},
        {"\<\"Paraboloidal\"\>", "\<\"ProlateSpheroidal\"\>"},
        {"\<\"Spherical\"\>", "\<\"Toroidal\"\>"},
        {"\[Null]", "\[Null]"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}}],
      GridBoxOptions->{
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}}}]], "2ColumnBox"]}]}]], "Text",
 TextAlignment->Center,
 TextJustification->0],

Cell[TextData[{
 "Por defecto, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " trabaja en coordenadas cartesianas ",
 StyleBox["x, y, z. ", "InlineFormula"],
 "Para obtener el cambio de cartesianas a, por ejemplo,  cil\[IAcute]ndricas, \
debemos escribir:"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"<<", "Calculus`VectorAnalysis`"}], "  "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], "}"}], "=", 
  RowBox[{"CoordinatesFromCartesian", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "Cylindrical"}], 
   "]"}]}]}], "Input",
 CellLabel->"In[1]:="],

Cell["\<\
que nos reproduce el conocido cambio de cartesianas a cil\[IAcute]ndricas. El \
cambio inverso se puede obtener mediante\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"x", ",", "y", ",", "z", ",", "\[Rho]", ",", "\[Phi]"}], "]"}], 
  "  ", 
  RowBox[{"(*", 
   RowBox[{
   "es", " ", "conveniente", " ", "borrar", " ", "antes", " ", "los", " ", 
    "valores", " ", "anteriores", " ", "para", " ", "evitar", " ", "errores", 
    " ", "recursivos"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}], "=", 
   RowBox[{"CoordinatesToCartesian", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], "}"}], ",", 
     "Cylindrical"}], "]"}]}], "\[IndentingNewLine]"}]}], "Input",
 CellLabel->"In[3]:="],

Cell[TextData[{
 "El vector ",
 Cell[BoxData[
  SubscriptBox[
   OverscriptBox["v", "\[RightVector]"], "\[Rho]"]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "\[Rho]"], " ", 
    OverscriptBox["r", "\[RightVector]"]}], TraditionalForm]]],
 " (tangente a  a las curvas \[Phi]=cte, z=cte), el ",
 Cell[BoxData[
  SubscriptBox[
   OverscriptBox["v", "\[RightVector]"], "\[Phi]"]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "\[Phi]"], " ", 
    OverscriptBox["r", "\[RightVector]"]}], TraditionalForm]]],
 " (tangente a  a las curvas r=cte, z=cte)  y el ",
 Cell[BoxData[
  SubscriptBox[
   OverscriptBox["v", "\[RightVector]"], "z"]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    OverscriptBox["r", "\[RightVector]"]}], TraditionalForm]]],
 " (tangente a  a las curvas r=cte, \[Phi]=cte) se calculan como:"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "=", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["v", "\[Rho]"], "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "\[Rho]"], "r"}], 
   " "}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["v", "\[Phi]"], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "\[Phi]"], "r"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["v", "z"], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "z"], "r"}]}]}], "Input",
 CellLabel->"In[5]:="],

Cell["\<\
De aqu\[IAcute] obtenemos los factores de escala:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  SubscriptBox["h", "\[Rho]"], "=", 
  RowBox[{"Simplify", "[", 
   SqrtBox[
    RowBox[{
     SubscriptBox["v", "\[Rho]"], ".", 
     SubscriptBox["v", "\[Rho]"]}]], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["h", "\[Phi]"], "=", 
  RowBox[{"Simplify", "[", 
   SqrtBox[
    RowBox[{
     SubscriptBox["v", "\[Phi]"], ".", 
     SubscriptBox["v", "\[Phi]"]}]], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["h", "z"], "=", 
   RowBox[{"Simplify", "[", 
    SqrtBox[
     RowBox[{
      SubscriptBox["v", "z"], ".", 
      SubscriptBox["v", "z"]}]], "]"}]}], "\[IndentingNewLine]"}]}], "Input",
 CellLabel->"In[9]:="],

Cell["\<\
Los vectores unitarios tangentes a las curvas coordenadas r, \[Theta], z son \
pues:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  SubscriptBox["e", "\[Rho]"], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    SubscriptBox["v", "\[Rho]"], "/", 
    SubscriptBox["h", "\[Rho]"]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["e", "\[Phi]"], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    SubscriptBox["v", "\[Phi]"], "/", 
    SubscriptBox["h", "\[Phi]"]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["e", "z"], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    SubscriptBox["v", "z"], "/", 
    SubscriptBox["h", "z"]}], "]"}]}]}], "Input",
 CellLabel->"In[12]:="],

Cell["\<\
y la matriz de paso de coordenadas cartesianas a cil\[IAcute]ndricas se puede \
escribir como:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cartesf", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["e", "\[Rho]"], ",", 
     SubscriptBox["e", "\[Phi]"], ",", 
     SubscriptBox["e", "z"]}], "}"}]}], ";", " ", 
  RowBox[{"MatrixForm", "[", "cartesf", "]"}]}]], "Input",
 CellLabel->"In[15]:="],

Cell[TextData[{
 "As\[IAcute], dado un campo de vectores ",
 StyleBox[Cell[BoxData[
  FormBox[
   OverscriptBox["F", "\[RightVector]"], TraditionalForm]], "InlineFormula"], 
  "InlineFormula"],
 StyleBox["=", "InlineFormula"],
 StyleBox[Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["F", "x"], "i"}], TraditionalForm]], "InlineFormula"], 
  "InlineFormula"],
 StyleBox["+", "InlineFormula"],
 StyleBox[Cell[BoxData[
  FormBox[
   SubscriptBox["F", "y"], TraditionalForm]], "InlineFormula"], 
  "InlineFormula"],
 StyleBox["j+", "InlineFormula"],
 StyleBox[Cell[BoxData[
  FormBox[
   SubscriptBox["F", "z"], TraditionalForm]], "InlineFormula"], 
  "InlineFormula"],
 StyleBox["k", "InlineFormula"],
 " en coordenadas cartesianas, las correspondientes componentes en \
coordenadas cil\[IAcute]ndricas ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["F", "\[RightVector]"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["F", "\[Rho]"], 
    SubscriptBox["e", "\[Rho]"]}], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["F", "\[Phi]"], 
    SubscriptBox["e", "\[Phi]"]}], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["F", "z"], 
    SubscriptBox["e", "z"]}], TraditionalForm]]],
 " se calculan:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"F\[Rho]", ",", "F\[Phi]", ",", "Fz"}], "}"}], "=", 
  RowBox[{"cartesf", ".", 
   RowBox[{"{", 
    RowBox[{"Fx", ",", "Fy", ",", "Fz"}], "}"}]}]}]], "Input",
 CellLabel->"In[16]:="],

Cell[TextData[{
 "Por ejemplo, dado el campo de vectores: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["F", "\[RightVector]"], "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", " ", "y"}], ",", " ", 
      RowBox[{
       SuperscriptBox["x", 
        RowBox[{"2", " "}]], "+", 
       SuperscriptBox["y", "2"]}], ",", 
      RowBox[{"x", "/", "y"}]}], ")"}]}], TraditionalForm]]],
 " en coordenadas cartesianas, sus componentes en coordenadas \
cil\[IAcute]ndricas son:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"F\[Rho]", ",", "F\[Phi]", ",", "Fz"}], "}"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"cartesf", ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "  ", "y"}], ",", " ", 
      RowBox[{
       SuperscriptBox["x", 
        RowBox[{"2", " "}]], "+", 
       SuperscriptBox["y", "2"]}], ",", 
      RowBox[{"x", "/", "y"}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[17]:="],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " dispone de comandos que realizan muchas de las anteriores operaciones. Por \
ejemplo, los vectores ",
 Cell[BoxData[
  SubscriptBox[
   OverscriptBox["v", "\[RightVector]"], "\[Rho]"]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "\[Rho]"], " ", 
    OverscriptBox["r", "\[RightVector]"]}], TraditionalForm]]],
 " (tangente a  a las curvas \[Phi]=cte, z=cte), el ",
 Cell[BoxData[
  SubscriptBox[
   OverscriptBox["v", "\[RightVector]"], "\[Phi]"]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "\[Phi]"], " ", 
    OverscriptBox["r", "\[RightVector]"]}], TraditionalForm]]],
 " (tangente a  a las curvas r=cte, z=cte)  y el ",
 Cell[BoxData[
  SubscriptBox[
   OverscriptBox["v", "\[RightVector]"], "z"]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    OverscriptBox["r", "\[RightVector]"]}], TraditionalForm]]],
 " (tangente a  a las curvas r=cte, \[Phi]=cte) aparecen como las columnas de \
la matriz jacobiana de la transformaci\[OAcute]n a coordenadas \
cil\[IAcute]ndricas, la cual se obtiene como:"
}], "Text"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"JacobianMatrix", "[", 
   RowBox[{"Cylindrical", "[", 
    RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], "]"}], "]"}], "]"}]], "Input",
 CellLabel->"In[18]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"o", " ", "sea"}], ","}]], "Text"],

Cell[BoxData[
 RowBox[{"v", "=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"JacobianMatrix", "[", 
    RowBox[{"Cylindrical", "[", 
     RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellLabel->"In[19]:="],

Cell["nos da una lista donde, por ejemplo, la primera fila", "Text"],

Cell[BoxData[
 RowBox[{"v", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[20]:="],

Cell[BoxData[
 StyleBox[
  RowBox[{"coincide", " ", "con", "  ", 
   SubscriptBox["v", "\[Rho]"], " ", "calculado", " ", 
   RowBox[{"anteriormente", ".", " ", "Tambi\[EAcute]n"}], " ", "existe", " ",
    "un", " ", "comando", " ", "para", " ", "obtener", " ", "los", " ", 
   "factores", " ", "de", " ", 
   RowBox[{"escala", ":"}]}],
  FontFamily->"Times New Roman"]], "Text"],

Cell[BoxData[
 RowBox[{"h", "=", 
  RowBox[{"ScaleFactors", "[", 
   RowBox[{"Cylindrical", "[", 
    RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], "]"}], "]"}]}]], "Input",
 CellLabel->"In[21]:="],

Cell["\<\
As\[IAcute], la matriz ortonormal de cambio de coordenadas cartesianas a esf\
\[EAcute]ricas se obtiene dividiendo los vectores tangentes por sus \
m\[OAcute]dulos (los factores de escala) como:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"e", "=", 
  RowBox[{"v", "/", "h"}]}]], "Input",
 CellLabel->"In[22]:="],

Cell[TextData[{
 "que coincide con la matriz ",
 StyleBox["cartesf ",
  FontWeight->"Bold"],
 "calculada anteriormente, cuyas filas son los vectores unitarios ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["e", "\[Rho]"], ",", 
    SubscriptBox["e", "\[Phi]"], " "}], TraditionalForm]]],
 "y ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "z"], TraditionalForm]]],
 ". En efecto:"
}], "Text"],

Cell[BoxData[{
 RowBox[{"e", "[", 
  RowBox[{"[", "1", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"e", "[", 
  RowBox[{"[", "2", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"e", "[", 
  RowBox[{"[", "3", "]"}], "]"}]}], "Input",
 CellLabel->"In[23]:="],

Cell[TextData[{
 "Vemos pues el significado y la utilidad de los comandos ",
 StyleBox["JacobianMatrix ",
  FontWeight->"Bold"],
 " y ",
 StyleBox["ScaleFactors",
  FontWeight->"Bold"],
 ", que hacen m\[AAcute]s f\[AAcute]cil el c\[AAcute]lculo de la matriz de \
cambio de base. Por otra parte, tenemos tambi\[EAcute]n un comando para el \
determinante de la matriz jacobiana:"
}], "Text"],

Cell[BoxData[
 RowBox[{"JacobianDeterminant", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], "]"}], "]"}]], "Input",
 CellLabel->"In[26]:="],

Cell["\<\
que coincide con el producto de los factores de escala. Este jacobiano \
aparece, como sabemos, en los cambios de coordenadas cartesianas a cil\
\[IAcute]ndricas en integrales triples.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "\nObtener la expresi\[OAcute]n del campo  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["F", "\[RightVector]"], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["F", "x"], ",", 
       SubscriptBox["F", "y"], ",", 
       SubscriptBox["F", "z"]}], ")"}], "=", 
     FractionBox[
      RowBox[{"(", 
       RowBox[{"yz", ",", " ", "xz", ",", "xy"}], ")"}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}]]]}]}], TraditionalForm]]],
 " en  coordenadas esf\[EAcute]ricas ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["F", "\[RightVector]"], "=", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["F", "r"], ",", 
      SubscriptBox["F", "\[Phi]"], ",", 
      SubscriptBox["F", "\[Theta]"]}], ")"}]}], TraditionalForm]]]
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Operadores vectoriales en coordenadas curvil\[IAcute]neas\
\>", "Subsection"],

Cell[TextData[{
 "Estamos en condiciones de obtener la expresi\[OAcute]n de los operadores \
vectoriales: Gradiente, Divergencia, Rotacional y Laplaciano, sobre funciones \
escalares y vectoriales dadas en diferentes sistemas de coordenadas. El \
sistema de coordenadas en que ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " trabaja por defecto es "
}], "Text"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"CoordinateSystem", ",", 
   RowBox[{"Coordinates", "[", "]"}]}], "}"}]], "Input",
 CellLabel->"In[27]:="],

Cell["\<\
es decir, coordenadas cartesianas representadas por defecto por: \
\"Xx,Yy,Zz\". Si queremos usar la nomenclatura usual: \"x,y,z\", o cualquier \
otra a nuestro gusto, deberemos usar el comando:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]}], "Input",
 CellLabel->"In[28]:="],

Cell[TextData[{
 "donde es conveniente borrar de memoria cualquier valor previo de x,y,z. \
Definamos una funci\[OAcute]n escalar ",
 StyleBox["f  ",
  FontWeight->"Bold"],
 "y otra vectorial ",
 StyleBox["v ",
  FontWeight->"Bold"],
 "arbitrarias:"
}], "Text"],

Cell["\<\
f[x,y,z]
v={vx[x,y,z],vy[x,y,z],vz[x,y,z]}\
\>", "Input",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 AspectRatioFixed->True,
 CellLabel->"In[30]:="],

Cell[TextData[{
 "Podemos obtener la expresi\[OAcute]n general del gradiente de ",
 StyleBox["f ",
  FontWeight->"Bold"],
 "en las coordenadas por defecto (cartesianas) escribiendo: "
}], "Text",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 Evaluatable->False,
 TextJustification->1,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Grad", "[", 
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input",
 CellLabel->"In[32]:="],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"donde", " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], "  ", "simboliza", " ", "la", 
    " ", "derivada", " ", "parcial", " ", "primera", " ", "de", 
    StyleBox[" ",
     FontWeight->"Bold"], 
    StyleBox["f",
     FontWeight->"Bold"], " ", "respecto", " ", "a", " ", 
    StyleBox["x",
     FontWeight->"Bold"], 
    StyleBox[" ",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"la", " ", "primera", " ", "coordenada"}], ")"}]}], ",", " ", 
   RowBox[{"y", " ", "as\[IAcute]", " ", 
    RowBox[{"sucesivamente", ".", " ", "El"}], " ", "rotacional", " ", "de", 
    " ", 
    StyleBox["v",
     FontWeight->"Bold"], 
    StyleBox[" ",
     FontWeight->"Bold"], 
    StyleBox["en",
     FontWeight->"Plain"], 
    StyleBox[" ",
     FontWeight->"Plain"], 
    StyleBox["cartesianas",
     FontWeight->"Plain"], 
    StyleBox[" ",
     FontWeight->"Plain"], 
    StyleBox["se",
     FontWeight->"Plain"], 
    StyleBox[" ",
     FontWeight->"Plain"], 
    StyleBox[
     RowBox[{"obtiene", ":"}],
     FontWeight->"Plain"]}]}],
  FontFamily->"Times New Roman"]], "Text"],

Cell["Curl[v]", "Input",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 AspectRatioFixed->True,
 CellLabel->"In[33]:="],

Cell[TextData[{
 "y la divergencia de ",
 StyleBox[" v",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Div[v]", "Input",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 TextJustification->1,
 AspectRatioFixed->True,
 CellLabel->"In[34]:="],

Cell["Proving the well known identity", "Text",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 Evaluatable->False,
 TextJustification->1,
 AspectRatioFixed->True],

Cell[TextData[{
 "Probemos que la divergencia del rotacional es nula: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Del]", 
     RowBox[{"\[Bullet]", "(", 
      RowBox[{
       RowBox[{"\[Del]", "x"}], 
       OverscriptBox[
        RowBox[{" ", "v"}], "\[RightVector]"]}], ")"}]}], "=", "0"}], 
   TraditionalForm]]],
 ":"
}], "Text",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}}],

Cell["Div[Curl[v]]", "Input",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 AspectRatioFixed->True,
 CellLabel->"In[35]:="],

Cell[TextData[{
 "as\[IAcute] como que el rotacional del gradiente es tambi\[EAcute]n cero: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Del]", 
     RowBox[{"x", "(", 
      RowBox[{"\[Del]", "f"}], ")"}]}], "=", "0"}], TraditionalForm]]]
}], "Text",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 Evaluatable->False,
 TextJustification->1,
 AspectRatioFixed->True],

Cell["Curl[Grad[f[x,y,z]]]", "Input",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 AspectRatioFixed->True,
 CellLabel->"In[36]:="],

Cell[TextData[{
 "El comando",
 StyleBox[" Laplacian ",
  FontWeight->"Bold"],
 "calcula el laplaciano \[CapitalDelta]=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Del]", "2"], "="}], TraditionalForm]]],
 "\[Del]\[FilledVerySmallSquare]\[Del] de una funci\[OAcute]n escalar"
}], "Text",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 Evaluatable->False,
 TextJustification->1,
 AspectRatioFixed->True],

Cell["Laplacian[f[x,y,z]]", "Input",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 AspectRatioFixed->True,
 CellLabel->"In[37]:="],

Cell["\<\
Podemos ver la expresi\[OAcute]n de estos operadores (gradiente, rotacional, \
divergencia y laplaciano) en otros sistemas de coordenadas. Por ejemplo, \
establezcamos como sistema de coordenadas por defecto el sistema de \
coordenadas esf\[EAcute]ricas:\
\>", "Text",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], "]"}]}], "Input",
 CellLabel->"In[38]:="],

Cell["\<\
El rango de variaci\[OAcute]n de las coordenadas r,\[Theta],\[Phi] en el \
sistema de coordenadas por defecto (ahora el esf\[EAcute]rico) viene dado \
por: \
\>", "Text"],

Cell[BoxData[
 RowBox[{"CoordinateRanges", "[", "]"}]], "Input",
 CellLabel->"In[40]:="],

Cell["\<\
El gradiente de una funci\[OAcute]n escalar en coordenadas esf\[EAcute]ricas \
es ahora:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Grad", "[", 
  RowBox[{"f", "[", 
   RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], "]"}]], "Input",
 CellLabel->"In[41]:="],

Cell["y el laplaciano:", "Text"],

Cell["Laplacian[f[r,\[Theta],\[Phi]]]", "Input",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 AspectRatioFixed->True,
 CellLabel->"In[42]:="],

Cell[TextData[{
 "La divergencia y el rotacional de un campo vectorial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FormBox[
      RowBox[{
       RowBox[{
        FormBox[
         OverscriptBox["V", "\[RightVector]"],
         TraditionalForm], 
        RowBox[{"(", 
         RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], ")"}]}], "=", 
       SubscriptBox["V", "r"]}],
      TraditionalForm], 
     SubscriptBox[
      OverscriptBox["e", "^"], "r"]}], "+", 
    RowBox[{
     SubscriptBox["V", "\[Theta]"], 
     SubscriptBox[
      OverscriptBox["e", "^"], "\[Theta]"]}], "+", 
    RowBox[{
     SubscriptBox["V", "\[Phi]"], 
     SubscriptBox[
      OverscriptBox["e", "^"], "\[Phi]"]}]}], TraditionalForm]]],
 " dado en esf\[EAcute]ricas tiene la siguiente \"pinta\":"
}], "Text"],

Cell[BoxData[{
 RowBox[{"Div", "[", 
  RowBox[{"{", 
   RowBox[{"Vr", ",", "V\[Theta]", ",", "V\[Phi]"}], "}"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Curl", "[", 
  RowBox[{"{", 
   RowBox[{"Vr", ",", "V\[Theta]", ",", "V\[Phi]"}], "}"}], "]"}]}], "Input",
 CellLabel->"In[43]:="],

Cell[TextData[{
 "Por ejemplo, tomemos como caso particular el campo gravitatorio ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["G", "\[RightVector]"], "=", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["r", "2"]], 
     OverscriptBox["r", "^"]}]}], TraditionalForm]]],
 ", y el campo ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["F", "\[RightVector]"], "=", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["r", "3"]], 
     OverscriptBox["r", "^"]}]}], TraditionalForm]]],
 " los cuales escribiremos como:"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"G", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"r", "^", "2"}]}], ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"r", "^", "3"}]}], ",", "0", ",", "0"}], "}"}]}], 
  ";"}]}], "Input",
 CellLabel->"In[45]:="],

Cell["La divergencia y el rotacional de estor campos es:", "Text"],

Cell[BoxData[{
 RowBox[{"Div", "[", "G", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Div", "[", "F", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Curl", "[", "G", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Curl", "[", "F", "]"}]}], "Input",
 CellLabel->"In[47]:="],

Cell[TextData[{
 "Que nos muestran que (salvo en ",
 StyleBox["r=0",
  FontSlant->"Italic"],
 " donde dichos campos no est\[AAcute]n definidos) el campo gravitatorio es \
solenoidal (tiene divergencia nula) y conservativo (rotacional nulo), \
mientras que el inverso del cubo de la distancia es tambi\[EAcute]n \
conservativo, pero no es solenoidal.\n\nPodemos calcular el rotacional y la \
divergencia  del campo de \"remolino\": ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FormBox[
      RowBox[{
       RowBox[{
        FormBox[
         OverscriptBox["V", "\[RightVector]"],
         TraditionalForm], "(", 
        RowBox[{"r", ",", "\[Phi]", ",", "z"}], ")"}], "=", 
       SubscriptBox["V", "\[Rho]"]}],
      TraditionalForm], 
     SubscriptBox[
      OverscriptBox["e", "^"], "\[Rho]"]}], "+", 
    RowBox[{
     SubscriptBox["V", "\[Phi]"], 
     SubscriptBox[
      OverscriptBox["e", "^"], "\[Phi]"]}], "+", 
    RowBox[{
     SubscriptBox["V", "z"], 
     OverscriptBox["k", "^"]}]}], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["\[Rho]", "2"]], 
    SubscriptBox[
     OverscriptBox["e", "^"], "\[Phi]"]}], TraditionalForm]]],
 " ",
 "en cil\[IAcute]ndricas sin necesidad de cambiar el sistema de coordenadas \
por defecto, mediante la opci\[OAcute]n:"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Curl", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"1", "/", 
      RowBox[{"\[Rho]", "^", "2"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"Cylindrical", "[", 
    RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Div", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"1", "/", 
      RowBox[{"\[Rho]", "^", "2"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"Cylindrical", "[", 
    RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], "]"}]}], "]"}]}], "Input",
 CellLabel->"In[51]:="],

Cell["\<\
que nos dice que el \"remolino\" es solenoidal (divergencia nula) e \
irrotacional (no conservativo).\
\>", "Text"],

Cell[TextData[{
 "Otros comandos \[UAcute]tiles son:",
 StyleBox[" \n\n",
  FontFamily->"B Times Bold"],
 StyleBox["CrossProduct[v1,v2]",
  FontFamily->"B Times Bold",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "que proporciona el producto vectorial, \n",
 StyleBox["DotProduct[v1,v2]",
  FontFamily->"B Times Bold",
  FontWeight->"Bold"],
 " ",
 "que proporciona el producto escalar y ",
 " \n",
 StyleBox["ScalarTripleProduct[v1,v2,v3]",
  FontFamily->"B Times Bold",
  FontWeight->"Bold"],
 " que da el producto escalar triple ",
 StyleBox["v1",
  FontFamily->"B Times Bold"],
 "\[Bullet](",
 StyleBox["v2",
  FontFamily->"B Times Bold"],
 " x ",
 StyleBox["v3",
  FontFamily->"B Times Bold"],
 ") (el volumen del paralelep\[IAcute]pedo definido por los vectores ",
 StyleBox["v1,v2,v3",
  FontFamily->"B Times Bold",
  FontWeight->"Bold"],
 StyleBox[") \n\n",
  FontFamily->"B Times Bold"],
 StyleBox["de vectores dados en un cierto sistema de coordenadas. Por \
ejemplo, los vectores ",
  FontFamily->"Times New Roman"]
}], "Text",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 Evaluatable->False,
 TextJustification->1,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"v1", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"v2", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[54]:="],

Cell[TextData[StyleBox["(dados en coordenadas cartesianas (x,y,z)) se \
escriben en coordenadas esf\[EAcute]ricas (r,\[Theta],\[Phi]) como:",
 FontFamily->"Times New Roman"]], "Text",
 CellMargins->{{Inherited, 50}, {Inherited, Inherited}},
 Evaluatable->False,
 TextJustification->1,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{"v1e", "=", 
  RowBox[{"CoordinatesFromCartesian", "[", 
   RowBox[{"v1", ",", "Spherical"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"v2e", "=", 
  RowBox[{"CoordinatesFromCartesian", "[", 
   RowBox[{"v2", ",", "Spherical"}], "]"}]}]}], "Input",
 CellLabel->"In[56]:="],

Cell["\<\
No obstante, su producto escalar no depende del sistema de coordenadas \
elegido:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"DotProduct", "[", 
  RowBox[{"v1e", ",", "v2e", ",", "Spherical"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DotProduct", "[", 
  RowBox[{"v1", ",", "v2", ",", "Cartesian"}], "]"}]}], "Input",
 CellLabel->"In[58]:="],

Cell[CellGroupData[{

Cell["Ejercicios", "Subsubsection",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{"1", ")"}],
     FontWeight->"Bold"], " ", "Dado", " ", "el", " ", 
    RowBox[{"campo", ":", " ", 
     StyleBox[
      RowBox[{
       OverscriptBox["F", "\[RightVector]"], 
       RowBox[{"(", 
        RowBox[{"x", ",", "y", ",", "z"}], ")"}]}],
      FontFamily->"Times New Roman"]}]}], 
   StyleBox["=",
    FontFamily->"Times New Roman"], 
   StyleBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["x", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"]}]], ",", 
       FractionBox["y", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"]}]], ",", "0"}], ")"}], " ", "en", " ", 
     "coordenadas", " ", "cartesianas"}],
    FontFamily->"Times New Roman"]}], 
  StyleBox[",",
   FontFamily->"Times New Roman"], 
  StyleBox[" ",
   FontFamily->"Times New Roman"], 
  StyleBox[
   RowBox[{
   "proporcione", " ", "su", " ", "expresi\[OAcute]n", " ", "en", " ", 
    "coordenadas", " ", "cil\[IAcute]ndricas", " ", "y", " ", "calcule", " ", 
    "su", " ", "divergencia", " ", "y", " ", "su", " ", 
    RowBox[{"rotacional", ".", " ", "\[DownQuestion]Es"}], " ", 
    RowBox[{"conservativo", "?"}]}],
   FontFamily->"Times New Roman"], 
  StyleBox[",",
   FontFamily->"Times New Roman"], 
  StyleBox[" ",
   FontFamily->"Times New Roman"], 
  StyleBox[
   RowBox[{"\[DownQuestion]es", " ", 
    RowBox[{"solenoidal", "?"}]}],
   FontFamily->"Times New Roman"]}]], "Text",
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 StyleBox["2)",
  FontWeight->"Bold"],
 " Dados los siguientes campos escalares f y vectoriales ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["V", "\[RightVector]"], TraditionalForm]]],
 " en coordenadas:\n\n cil\[IAcute]ndricas:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["f", "1"], "(", 
     RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], ")"}], "=", 
    RowBox[{
     SuperscriptBox["\[Rho]", "3"], " ", 
     SuperscriptBox["z", "4"], " ", 
     RowBox[{"sin", "(", "\[Phi]", ")"}]}]}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["V", "\[RightVector]"], "1"], "(", 
     RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], ")"}], "=", 
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox["z", "2"], ",", "2", ",", "\[Rho]"}], "}"}]}], 
   TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["f", "2"], "(", 
     RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], ")"}], "=", 
    RowBox[{
     SuperscriptBox["z", "3"], " ", "\[Rho]"}]}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     OverscriptBox["V", "\[RightVector]"], "2"], "(", 
    RowBox[{"\[Rho]", ",", "\[Phi]", ",", "z"}], ")"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"cos", "(", "\[Phi]", ")"}], ",", 
      RowBox[{"-", 
       RowBox[{"sin", "(", "\[Phi]", ")"}]}], ",", "0"}], "}"}]}], 
   TraditionalForm]]],
 "\n\ny esf\[EAcute]ricas:\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "3"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], ")"}], "=", 
    RowBox[{"r", " ", 
     RowBox[{"sin", "(", "\[Phi]", ")"}]}]}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["V", "3"], "\[RightVector]"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], ")"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sin", "(", "\[Phi]", ")"}], ",", " ", "0", ",", " ", 
      RowBox[{"cos", "(", "\[Theta]", ")"}]}], "}"}]}], TraditionalForm]]],
 "\n\nCalcular:\n2.a) El gradiente, la divergencia y el rotacional. \
\[DownQuestion]Qu\[EAcute] campos son conservativos?, \[DownQuestion]cu\
\[AAcute]les son solenoidales?.\n2.b) Verifique que el rotacional del \
gradiente y la divergencia del rotacional son nulos"
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"],

Cell[TextData[{
 StyleBox["3) ",
  FontWeight->"Bold"],
 "Verifique que: \n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Psi]", "1"], TraditionalForm]]],
 "(\[Rho]",
 StyleBox[",\[Phi],z)=",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Rho]", "n"], 
    RowBox[{"cos", "(", 
     RowBox[{"n", " ", "\[Phi]"}], ")"}]}], TraditionalForm]]],
 " , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Psi]", "2"], TraditionalForm]]],
 "(\[Rho]",
 StyleBox[",\[Phi],z)",
  FontSlant->"Italic"],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Rho]", "n"], 
    RowBox[{"sin", "(", 
     RowBox[{"n", " ", "\[Phi]"}], ")"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Psi]", "3"], TraditionalForm]]],
 "(\[Rho]",
 StyleBox[",\[Phi],z)=",
  FontSlant->"Italic"],
 "  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"ln", " ", "\[Rho]"}], TraditionalForm]]],
 " ,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Psi]", "4"], TraditionalForm]]],
 "(\[Rho]",
 StyleBox[",\[Phi],z)=",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["\[Rho]", "2"], "+", 
      SuperscriptBox["z", "2"]}]]], TraditionalForm]]],
 "\n\nson soluciones de la ecuaci\[OAcute]n de Laplace ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Del]", "2"], "\[Psi]"}], "=", "0"}], TraditionalForm]]],
 " en coordenadas cil\[IAcute]ndricas."
}], "Text",
 ShowGroupOpener->True,
 Evaluatable->False,
 AspectRatioFixed->True,
 FontFamily->"New York"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingStartingPageNumber->101,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      OptionValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      OptionValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"FacingPages"->True,
"FirstPageHeader"->False,
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{72, 72}, {57.5625, 57.5625}}},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Textbook.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 180, 6, 82, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[772, 32, 111, 3, 38, "Subsection"],
Cell[886, 37, 843, 14, 71, "Text"],
Cell[1732, 53, 998, 23, 182, "Text"],
Cell[2733, 78, 275, 8, 23, "Text"],
Cell[3011, 88, 379, 11, 49, "Input"],
Cell[3393, 101, 144, 3, 23, "Text"],
Cell[3540, 106, 696, 19, 69, "Input"],
Cell[4239, 127, 932, 32, 26, "Text"],
Cell[5174, 161, 564, 19, 89, "Input"],
Cell[5741, 182, 73, 2, 25, "Text"],
Cell[5817, 186, 681, 23, 97, "Input"],
Cell[6501, 211, 108, 3, 25, "Text"],
Cell[6612, 216, 592, 19, 70, "Input"],
Cell[7207, 237, 118, 3, 25, "Text"],
Cell[7328, 242, 294, 9, 30, "Input"],
Cell[7625, 253, 1315, 47, 27, "Text"],
Cell[8943, 302, 234, 7, 30, "Input"],
Cell[9180, 311, 503, 16, 26, "Text"],
Cell[9686, 329, 438, 14, 31, "Input"],
Cell[10127, 345, 1196, 37, 43, "Text"],
Cell[11326, 384, 212, 5, 30, "Input"],
Cell[11541, 391, 68, 2, 25, "Text"],
Cell[11612, 395, 241, 7, 30, "Input"],
Cell[11856, 404, 68, 0, 25, "Text"],
Cell[11927, 406, 101, 3, 30, "Input"],
Cell[12031, 411, 378, 8, 27, "Text"],
Cell[12412, 421, 196, 5, 30, "Input"],
Cell[12611, 428, 218, 4, 25, "Text"],
Cell[12832, 434, 96, 3, 30, "Input"],
Cell[12931, 439, 406, 15, 26, "Text"],
Cell[13340, 456, 259, 7, 70, "Input"],
Cell[13602, 465, 389, 10, 42, "Text"],
Cell[13994, 477, 178, 4, 30, "Input"],
Cell[14175, 483, 208, 4, 25, "Text"],
Cell[CellGroupData[{
Cell[14408, 491, 34, 0, 37, "Subsubsection"],
Cell[14445, 493, 898, 30, 61, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15392, 529, 87, 2, 44, "Subsection"],
Cell[15482, 533, 368, 8, 42, "Text"],
Cell[15853, 543, 145, 4, 30, "Input"],
Cell[16001, 549, 218, 4, 25, "Text"],
Cell[16222, 555, 274, 7, 50, "Input"],
Cell[16499, 564, 261, 9, 25, "Text"],
Cell[16763, 575, 173, 6, 52, "Input"],
Cell[16939, 583, 321, 9, 25, "Text",
 Evaluatable->False],
Cell[17263, 594, 143, 4, 30, "Input"],
Cell[17409, 600, 1319, 45, 26, "Text"],
Cell[18731, 647, 130, 3, 32, "Input"],
Cell[18864, 652, 199, 8, 25, "Text",
 Evaluatable->False],
Cell[19066, 662, 152, 4, 32, "Input"],
Cell[19221, 668, 173, 4, 25, "Text",
 Evaluatable->False],
Cell[19397, 674, 403, 14, 25, "Text"],
Cell[19803, 690, 135, 3, 32, "Input"],
Cell[19941, 695, 388, 12, 25, "Text",
 Evaluatable->False],
Cell[20332, 709, 143, 3, 32, "Input"],
Cell[20478, 714, 430, 14, 25, "Text",
 Evaluatable->False],
Cell[20911, 730, 142, 3, 32, "Input"],
Cell[21056, 735, 381, 8, 42, "Text",
 Evaluatable->False],
Cell[21440, 745, 301, 8, 50, "Input"],
Cell[21744, 755, 180, 4, 25, "Text"],
Cell[21927, 761, 88, 2, 30, "Input"],
Cell[22018, 765, 112, 3, 25, "Text"],
Cell[22133, 770, 155, 4, 30, "Input"],
Cell[22291, 776, 32, 0, 25, "Text"],
Cell[22326, 778, 154, 3, 32, "Input"],
Cell[22483, 783, 802, 27, 27, "Text"],
Cell[23288, 812, 287, 8, 50, "Input"],
Cell[23578, 822, 568, 20, 30, "Text"],
Cell[24149, 844, 391, 15, 50, "Input"],
Cell[24543, 861, 66, 0, 25, "Text"],
Cell[24612, 863, 255, 5, 90, "Input"],
Cell[24870, 870, 1356, 42, 115, "Text"],
Cell[26229, 914, 715, 22, 70, "Input"],
Cell[26947, 938, 125, 3, 25, "Text"],
Cell[27075, 943, 1181, 41, 185, "Text",
 Evaluatable->False],
Cell[28259, 986, 281, 9, 50, "Input"],
Cell[28543, 997, 309, 6, 25, "Text",
 Evaluatable->False],
Cell[28855, 1005, 297, 7, 50, "Input"],
Cell[29155, 1014, 105, 3, 25, "Text"],
Cell[29263, 1019, 241, 5, 50, "Input"],
Cell[CellGroupData[{
Cell[29529, 1028, 130, 4, 37, "Subsubsection",
 Evaluatable->False],
Cell[29662, 1034, 1598, 51, 65, "Text"],
Cell[31263, 1087, 2653, 88, 420, "Text",
 Evaluatable->False],
Cell[33919, 1177, 1599, 68, 135, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

