(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     48030,       1619]
NotebookOptionsPosition[     43371,       1473]
NotebookOutlinePosition[     44432,       1512]
CellTagsIndexPosition[     44389,       1509]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Ecuaciones diferenciales ordinarias", "Section",
 ShowGroupOpener->True,
 GeneratedCell->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Soluciones exactas con DSolve",
 FontFamily->"Times New Roman"]], "Subsection",
 ShowGroupOpener->True,
 GeneratedCell->False],

Cell[CellGroupData[{

Cell["Resumen de comandos", "Subsubsection"],

Cell[TextData[{
 StyleBox["DSolve[edo==0,y,x] ",
  FontWeight->"Bold"],
 " da la soluci\[OAcute]n general de una EDO en t\[EAcute]rminos de la funci\
\[OAcute]n ",
 StyleBox["y[x]",
  FontWeight->"Bold"],
 ".",
 StyleBox["\n\nDSolve[{edo==0,condinic},y,x] ",
  FontWeight->"Bold"],
 " resuelve una EDO en t\[EAcute]rminos de la funci\[OAcute]n ",
 StyleBox["y[x] ",
  FontWeight->"Bold"],
 "con condiciones iniciales ",
 StyleBox["condinic",
  FontWeight->"Bold"],
 ".\n\n",
 StyleBox["DSolve[{edo1==0,edo2==0,...},{y1,y2,...},x] ",
  FontWeight->"Bold"],
 " resuelve un sistema de EDOs en t\[EAcute]rminos de las funciones ",
 StyleBox["y1[x], y2[x]",
  FontWeight->"Bold"],
 ", etc.\n\n",
 StyleBox["DSolve[edp==0,y,{x1,x2,...}] ",
  FontWeight->"Bold"],
 " resuelve una EDP (ecuaci\[OAcute]n en derivadas parciales) en \
t\[EAcute]rminos de la funci\[OAcute]n ",
 StyleBox["y[x1,x2,...]",
  FontWeight->"Bold"],
 ".\n\nel paquete ",
 StyleBox["<<Calculus`DSolveIntegrals` ",
  FontWeight->"Bold"],
 "proporciona \"integrales completas\" para EDPs mediante el comando:",
 StyleBox["\nCompleteIntegral[edp==0,y,{x1,x2,...}] ",
  FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
 StyleBox["El comando",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Courier"],
 StyleBox["DSolve",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " encuentra soluciones anal\[IAcute]ticas (no num\[EAcute]ricas) para un n\
\[UAcute]mero cada vez mayor de ecuaciones diferenciales. Por ejemplo:\n\
\[FilledSmallSquare] ",
 StyleBox["DSolve", "MR"],
 " resuelve EDOs lineales con coeficientes constantes de cualquier orden y \
muchas ecuaciones lineales de hasta segundo orden con coeficientes no \
constantes.\n\[FilledSmallSquare] ",
 StyleBox["DSolve", "MR"],
 " incluye procedimientos generales para EDOs no lineales cuyas soluciones \
vienen tratadas en libros de texto y manuales.\n\[FilledSmallSquare] ",
 StyleBox["DSolve", "MR"],
 " puede encontrar soluciones generales para ecuaciones en derivadas \
parciales lineales (y \"d\[EAcute]bilmente no lineales\"). T\[EAcute]ngase en \
cuenta que las ecuaciones diferenciales en derivadas parciales no lineales no \
presentan usualmente una soluci\[OAcute]n general expl\[IAcute]cita \
(\[EAcute]ste es un campo de investigaci\[OAcute]n  importante donde es \
necesario avanzar)"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Ejemplos de EDOs de orden 1. Isoclinas y m\[EAcute]todo de Euler\
\>", "Subsubsection"],

Cell[TextData[{
 "Consideremos la ecuaci\[OAcute]n diferencial  ",
 StyleBox["y",
  FontSlant->"Italic"],
 "'",
 StyleBox["=x.",
  FontSlant->"Italic"],
 " El campo de direcciones (isoclinas) asociado a esta ecuaci\[OAcute]n \
diferencial es ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["v", "\[RightVector]"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", ",", 
       RowBox[{"y", "'"}]}], ")"}], "=", 
     RowBox[{"(", 
      RowBox[{"1", ",", "x"}], ")"}]}]}], TraditionalForm]]],
 ", que representan vectores tangentes a la trayectoria ",
 StyleBox["y(x) ",
  FontSlant->"Italic"],
 " en cada punto. La representaci\[OAcute]n gr\[AAcute]fica del mismo se \
realiza mediante:"
}], "Text"],

Cell[BoxData[{
 RowBox[{"<<", "Graphics`PlotField`"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"isoclinas", "=", 
   RowBox[{"PlotVectorField", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "x"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[1]:="],

Cell[TextData[{
 "La soluci\[OAcute]n general de la ecuaci\[OAcute]n diferencial ",
 StyleBox["y'=x ",
  FontSlant->"Italic"],
 " viene dada por:"
}], "Text"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "'"}], "[", "x", "]"}], "==", "x"}], ",", 
   RowBox[{"y", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
 CellLabel->"In[3]:="],

Cell[TextData[{
 "que nos da una familia uniparam\[EAcute]trica de curvas, donde C[1] \
representa la constante de integraci\[OAcute]n. Representemos varias curvas \
de esta familia pero, para ello, definamos la familia ",
 StyleBox["y(x,c) ",
  FontSlant->"Italic"],
 "para distintas condiciones iniciales ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", "0", ")"}], "=", "c"}], TraditionalForm]]],
 " como una funci\[OAcute]n ",
 StyleBox["sol[x,c] ",
  FontWeight->"Bold"],
 "de dos variables:"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"y", ",", "x", ",", "c"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "[", 
   RowBox[{"x_", ",", "c_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"y", "[", "x", "]"}], "/.", 
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"y", "'"}], "[", "x", "]"}], "==", "x"}], ",", 
       RowBox[{
        RowBox[{"y", "[", "0", "]"}], "==", "c"}]}], "}"}], ",", 
     RowBox[{"y", "[", "x", "]"}], ",", "x"}], "]"}]}]}]}], "Input",
 CellLabel->"In[4]:="],

Cell["\<\
Definamos una tabla con los 7 miembros c=-2,-1.5,...,0.5,1 de dicha familia \
uniparam\[EAcute]trica de curvas y represent\[EAcute]mosla \
gr\[AAcute]ficamente:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"familia", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"sol", "[", 
      RowBox[{"x", ",", "c"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", 
       RowBox[{"-", "2"}], ",", "1", ",", "0.5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"familiaplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "familia", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "]"}]}]}], "Input",
 CellLabel->"In[6]:="],

Cell["\<\
Superponiendo dichas curvas con el campo de direcciones (isoclinas):\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"isoclinas", ",", "familiaplot"}], "]"}]], "Input",
 CellLabel->"In[8]:="],

Cell["\<\
vemos que el campo de direcciones es, efectivamente, tangente a la familia de \
curvas en cada punto.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Dibuje el campo de direcciones (isoclinas) de la ecuaci\[OAcute]n \
diferencial ",
 StyleBox["y'=",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "3"], TraditionalForm]]],
 "-",
 StyleBox["x ",
  FontSlant->"Italic"],
 "en el cuadrado ",
 StyleBox["(x,y)",
  FontSlant->"Italic"],
 "\[Epsilon][-2,2]\[Times][-3,3]",
 StyleBox[" ",
  FontSlant->"Italic"],
 "y superponga dicho gr\[AAcute]fico al de la familia de soluciones con \
condiciones iniciales  ",
 StyleBox["y(0)=c=-1,-0.5,0,0.5,1",
  FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
 StyleBox["M\[EAcute]todo de Euler: ",
  FontWeight->"Bold"],
 "Aunque ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " dispone de m\[EAcute]todos num\[EAcute]ricos relativamente exactos para \
resolver ecuaciones diferenciales, dise\[NTilde]emos nosotros mismos un \
algoritmo para un m\[EAcute]todo \"grosero\" (poco preciso, no refinado) c\
\[OAcute]mo es el de Euler. Esto nos sirve como \"modelo de juguete\" para \
saber cualitativamente c\[OAcute]mo funcionan otros m\[EAcute]todos num\
\[EAcute]ricos m\[AAcute]s sofisticados y c\[OAcute]mo evaluar el error num\
\[EAcute]rico cometido. Por ejemplo, tomemos la ecuaci\[OAcute]n lineal no \
homog\[EAcute]nea de primer orden ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", "'"}], "=", 
     RowBox[{
      RowBox[{"f", "(", 
       RowBox[{"x", ",", "y"}], ")"}], "=", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", "y"}]}]}], ","}], TraditionalForm]]],
 " con la condici\[OAcute]n inicial ",
 StyleBox["y(0)=1. ",
  FontSlant->"Italic"],
 "Aunque s",
 "abemos resolver dicha ecuaci\[OAcute]n de forma exacta, abordaremos el \
problema de forma num\[EAcute]rica y compararemos la soluci\[OAcute]n num\
\[EAcute]rica con la exacta para evaluar el error cometido y as\[IAcute] \
hacer un test a nuestro m\[EAcute]todo num\[EAcute]rico. Supongamos que \
queremos una soluci\[OAcute]n num\[EAcute]rica de la EDO anterior en el \
intervalo x\[Element][0,1]. Para ello dividimos el intervalo [0,1] en, por \
ejemplo, 10 trozos, tomando un paso ",
 StyleBox["h=0.1 ",
  FontSlant->"Italic"],
 "y obteniendo as\[IAcute] 11 puntos equiespaciados: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], "=", "0"}], ",", " ", 
    RowBox[{
     SubscriptBox["x", "1"], "=", "0.1"}], ",", " ", "...", ",", " ", 
    RowBox[{
     SubscriptBox["x", "k"], "=", 
     RowBox[{
      SubscriptBox["x", "0"], "+", 
      RowBox[{"k", " ", "h"}]}]}], ",", " ", "...", ",", " ", 
    RowBox[{
     SubscriptBox["x", "10"], "=", "1"}]}], TraditionalForm]]],
 ". Introduzcamos dicha informaci\[OAcute]n en el programa:"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"f", ",", "x", ",", "y", ",", "h", ",", "k"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"x", "^", "2"}], "+", "y"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h", "=", "0.1"}], ";", 
  RowBox[{
   RowBox[{"x", "[", "0", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "[", "k_", "]"}], ":=", 
  RowBox[{
   RowBox[{"x", "[", "0", "]"}], "+", 
   RowBox[{"k", "*", "h"}]}]}]}], "Input",
 CellLabel->"In[9]:="],

Cell[TextData[{
 "Discretizando la derivada ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "'"}], 
      RowBox[{"(", 
       SubscriptBox["x", "k"], ")"}]}], "\[TildeTilde]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"y", "(", 
         SubscriptBox["x", 
          RowBox[{"k", "+", "1"}]], ")"}], "-", 
        RowBox[{"y", "(", 
         SubscriptBox["x", "k"], ")"}]}], ")"}], "/", "h"}]}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["y", 
        RowBox[{"k", "+", "1"}]], "-", 
       SubscriptBox["y", "k"]}], ")"}], "/", "h"}]}], TraditionalForm]]],
 " obtenemos la versi\[OAcute]n en diferencias finitas ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["y", "k"], "=", 
    RowBox[{
     SubscriptBox["y", 
      RowBox[{"k", "-", "1"}]], "+", 
     RowBox[{"h", " ", 
      RowBox[{"f", "(", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"k", "-", "1"}]], ",", 
        SubscriptBox["y", 
         RowBox[{"k", "-", "1"}]]}], ")"}]}]}]}], TraditionalForm]]],
 "   de la ecuaci\[OAcute]n diferencial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "'"}], "=", 
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{"x", ",", "y"}], ")"}], ".", " "}]}], TraditionalForm]]],
 "Introduzcamos dicha ecuaci\[OAcute]n en el programa y representemos los 11 \
puntos ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}], ",", "...", ",", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "10"], ",", 
      SubscriptBox["y", "10"]}], ")"}]}], TraditionalForm]]],
 ":"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"k", "-", "1"}], "]"}], "+", 
    RowBox[{"h", "*", 
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"k", "-", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"k", "-", "1"}], "]"}]}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"eulerplot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "k", "]"}], ",", 
       RowBox[{"y", "[", "k", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "10"}], "}"}]}], "]"}], "]"}]}]}], "Input",
 CellLabel->"In[13]:="],

Cell["\<\
Calculemos la soluci\[OAcute]n exacta y represent\[EAcute]mosla \
gr\[AAcute]ficamente (cambiaremos x\[LeftRightArrow]t, y\[LeftRightArrow]z \
para evitar incompatibilidades)\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"exacta", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}], "==", 
       RowBox[{
        RowBox[{"t", "^", "2"}], "+", 
        RowBox[{"z", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"z", "[", "0", "]"}], "==", "1"}]}], "}"}], ",", "z", ",", 
    "t"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"exactaplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "t", "]"}], "/.", "exacta"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}], "Input",
 CellLabel->"In[16]:="],

Cell["\<\
Superpongamos la soluci\[OAcute]n exacta y la num\[EAcute]rica:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"eulerplot", ",", "exactaplot"}], "]"}]], "Input",
 CellLabel->"In[18]:="],

Cell[TextData[{
 "Vemos c\[OAcute]mo la soluci\[OAcute]n num\[EAcute]rica  se aparta \
progresivamente de la exacta conforme nos alejamos del punto inicial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"0", ",", "1"}], ")"}]}], TraditionalForm]]],
 ". Podemos evaluar el error cometido en el \[UAcute]ltimo punto ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "10"], ",", 
      SubscriptBox["y", "10"]}], ")"}], " "}], TraditionalForm]]],
 StyleBox[" ",
  FontSlant->"Italic"],
 "como ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", "1", ")"}], "-", 
    SubscriptBox["y", "10"]}], TraditionalForm]]],
 ":"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Evaluate", "[", 
   RowBox[{
    RowBox[{"z", "[", "1", "]"}], "/.", "exacta"}], "]"}], "-", 
  RowBox[{"y", "[", "10", "]"}]}]], "Input",
 CellLabel->"In[19]:="],

Cell["Es decir, el error es de 0.214244", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Repita los pasos anteriores para 21 puntos, es decir, tomando como paso la \
mitad del anterior: ",
 StyleBox["h=0.05. ",
  FontSlant->"Italic"],
 "Eval\[UAcute]e el error cometido en el c\[AAcute]lculo num\[EAcute]rico de ",
 StyleBox["y(1).",
  FontSlant->"Italic"],
 " \[DownQuestion]Es el error mayor o menor que para el caso ",
 StyleBox["h=0.1",
  FontSlant->"Italic"],
 "?."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejemplos de EDOs de orden 2. Diagrama de fases", "Subsubsection"],

Cell[TextData[{
 "Consideremos la ecuaci\[OAcute]n diferencial lineal de segundo orden con \
coeficientes constantes x",
 StyleBox["''(t)=kx(t) ",
  FontSlant->"Italic"],
 " que puede representar la ecuaci\[OAcute]n de un oscilador arm\[OAcute]nico \
simple atractivo para ",
 StyleBox["k<0 ",
  FontSlant->"Italic"],
 " y repulsivo para ",
 StyleBox["k>0. ",
  FontSlant->"Italic"],
 " La soluci\[OAcute]n general de esta ecuaci\[OAcute]n se obtiene:"
}], "Text",
 ShowGroupOpener->True,
 GeneratedCell->False],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"x", ",", "t"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "''"}], "[", "t", "]"}], "==", 
    RowBox[{"k", " ", 
     RowBox[{"x", "[", "t", "]"}]}]}], ",", 
   RowBox[{"x", "[", "t", "]"}], ",", "t"}], "]"}]}], "Input",
 ShowGroupOpener->True,
 GeneratedCell->False,
 CellLabel->"In[20]:="],

Cell[TextData[{
 "Vemos que contiene dos constantes arbitrarias C[1] y C[2], como corresponde \
a una EDO de orden 2. \n\nTomemos el oscilador atractivo con ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["\[Omega]", "0", "2"]}], "="}]}], TraditionalForm]]],
 "-2 y condiciones iniciales x",
 StyleBox["(0)=1, x'(0)=0 ",
  FontSlant->"Italic"],
 "(velocidad inicial nula); ahora la soluci\[OAcute]n ser\[AAcute]:"
}], "Text"],

Cell[BoxData[
 RowBox[{"xoscatract", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "''"}], "[", "t", "]"}], "==", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"x", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"x", "[", "0", "]"}], "==", "1"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "'"}], "[", "0", "]"}], "==", "0"}]}], "}"}], ",", "x", 
    ",", "t"}], "]"}]}]], "Input",
 CellLabel->"In[22]:="],

Cell[TextData[{
 "que representa un movimiento arm\[OAcute]nico simple de amplitud 1 y \
frecuencia ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Omega]", "0"], "=", 
    SqrtBox["2"]}], TraditionalForm]]],
 ". Para representar  gr\[AAcute]ficamente la posici\[OAcute]n ",
 StyleBox["x",
  FontWeight->"Bold"],
 " en funci\[OAcute]n del tiempo ",
 StyleBox["t ",
  FontWeight->"Bold"],
 "escribiremos:"
}], "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "t", "]"}], "/.", "xoscatract"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "Pi"}]}], "}"}], ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<t\>\"", ",", "\"\<x[t]\>\""}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[23]:="],

Cell[TextData[{
 "donde observamos que el periodo del movimiento es ",
 StyleBox["T=",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"2", "\[Pi]"}], 
     SubscriptBox["\[Omega]", "0"]], "=", 
    RowBox[{
     RowBox[{"2", 
      RowBox[{"\[Pi]", "/", 
       SqrtBox["2"]}]}], "\[TildeTilde]", "4.442882938158366`"}]}], 
   TraditionalForm]]],
 ". Para representar la velocidad ",
 StyleBox["v[t]=x'[t] ",
  FontWeight->"Bold"],
 "en funci\[OAcute]n del tiempo escribimos:"
}], "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "'"}], "[", "t", "]"}], "/.", "xoscatract"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"Pi", "/", 
       SqrtBox["2"]}]}]}], "}"}], ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<t\>\"", ",", "\"\<v[t]\>\""}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[24]:="],

Cell[TextData[{
 "Tambi\[EAcute]n podemos hacer una representaci\[OAcute]n de la velocidad ",
 StyleBox["v[x]",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "en funci\[OAcute]n de la posici\[OAcute]n ",
 StyleBox["x ",
  FontWeight->"Bold"],
 "(\"diagrama de fases\") por medio de un gr\[AAcute]fico en forma param\
\[EAcute]trica:"
}], "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}]}], "}"}], "/.", "xoscatract"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"Pi", "/", 
       SqrtBox["2"]}]}]}], "}"}], ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<v[x]\>\""}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[25]:="],

Cell[TextData[{
 "que nos da una \[OAcute]rbita cerrada (elipse), caracter\[IAcute]stica de \
los sistemas peri\[OAcute]dicos.\n\nVeamos qu\[EAcute] pasa con el oscilador \
repulsivo para ",
 StyleBox["k=2 ",
  FontSlant->"Italic"],
 "e id\[EAcute]nticas condiciones iniciales que para el atractivo"
}], "Text"],

Cell[BoxData[{
 RowBox[{"xoscrepul", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "''"}], "[", "t", "]"}], "==", 
       RowBox[{"2", " ", 
        RowBox[{"x", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"x", "[", "0", "]"}], "==", "1"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "'"}], "[", "0", "]"}], "==", "0"}]}], "}"}], ",", "x", 
    ",", "t"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "t", "]"}], "/.", "xoscrepul"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "Pi"}], "}"}], ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<t\>\"", ",", "\"\<x[t]\>\""}], "}"}]}]}], "]"}]}], "Input",
 CellLabel->"In[26]:="],

Cell[TextData[{
 "Vemos que la part\[IAcute]cula se aleja de su posici\[OAcute]n inicial ",
 StyleBox["x(0)=1 ",
  FontSlant->"Italic"],
 " de forma exponencial. La trayectoria no se repite a intervalos de tiempo \
fijos ",
 StyleBox["T;",
  FontSlant->"Italic"],
 " es decir, a diferencia del oscilador atractivo, el oscilador repulsivo no \
es un sistema peri\[OAcute]dico. Veamos que sus trayectorias en el plano de \
fases tampoco son cerradas:"
}], "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}]}], "}"}], "/.", "xoscrepul"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"Pi", "/", 
       SqrtBox["2"]}]}]}], "}"}], ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<v[x]\>\""}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[28]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Dibuje la trayectoria en el plano ",
 StyleBox["x-t ",
  FontWeight->"Bold"],
 " y en el plano de fases ",
 StyleBox["x-x' ",
  FontWeight->"Bold"],
 "de un oscilador arm\[OAcute]nico simple atractivo con ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["\[Omega]", "0", "2"]}], "=", 
     RowBox[{"-", "5"}]}]}], TraditionalForm]]],
 " que parte de la posici\[OAcute]n ",
 StyleBox["x(0)=0 ",
  FontSlant->"Italic"],
 "con velocidad ",
 StyleBox["x'(0)=1. ",
  FontSlant->"Italic"],
 "Tome el intervalo ",
 StyleBox["t\[Element][0,",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "=", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], 
     SubscriptBox["\[Omega]", "0"]]}], TraditionalForm]]],
 StyleBox["].",
  FontSlant->"Italic"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sistemas de EDOs", "Subsubsection"],

Cell[TextData[{
 "Tambi\[EAcute]n podemos resolver sistemas de EDOs,introduciendo \
\[EAcute]stas mediante una lista.Por ejemplo, para resolver el sistema de dos \
EDOs lineales con coeficientes constantes ",
 Cell[BoxData[
  FormBox[
   TagBox[
    StyleBox[
     RowBox[{"{", 
      StyleBox[GridBox[{
         {
          RowBox[{
           SubscriptBox["y", "1"], "=", 
           RowBox[{"-", 
            RowBox[{
             SubscriptBox["y", "2"], "'"}]}]}]},
         {
          RowBox[{
           SubscriptBox["y", "2"], "=", 
           RowBox[{"-", 
            RowBox[{
             SubscriptBox["y", "1"], "'"}]}]}]}
        }],
       ShowAutoStyles->True]}],
     ShowAutoStyles->False],
    #& ], TraditionalForm]]],
 "  escribiremos:"
}], "Text"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"y1", "[", "x", "]"}], "==", 
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["y2", "\[Prime]",
         MultilineFunction->None], "[", "x", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"y2", "[", "x", "]"}], "==", 
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["y1", "\[Prime]",
         MultilineFunction->None], "[", "x", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"y1", "[", "x", "]"}], ",", 
     RowBox[{"y2", "[", "x", "]"}]}], "}"}], ",", "x"}], "]"}]], "Input",
 CellLabel->"In[29]:="],

Cell[TextData[{
 "que nos da la soluci\[OAcute]n general dependiente de dos constantes \
arbitrarias C[1] y C[2].Veamos c\[OAcute]mo calcular la soluci\[OAcute]n \
particular que pasa por ",
 StyleBox["{y1[0],y2[0]}={1,2}",
  FontWeight->"Bold"],
 " y c\[OAcute]mo representar ",
 StyleBox["y1[t]",
  FontWeight->"Bold"],
 " e ",
 StyleBox["y2[t]",
  FontWeight->"Bold"],
 " superpuestas en un mismo gr\[AAcute]fico:"
}], "Text"],

Cell[BoxData[{
 RowBox[{"sistema", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"y1", "[", "x", "]"}], "==", 
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox["y2", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"y1", "[", "0", "]"}], "==", "1"}], ",", 
      RowBox[{
       RowBox[{"y2", "[", "x", "]"}], "==", 
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox["y1", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"y2", "[", "0", "]"}], "==", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y1", ",", "y2"}], "}"}], ",", "x"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Graphics`Legend`"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"y1", "[", "t", "]"}], "/.", "sistema"}], "]"}], ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"y2", "[", "t", "]"}], "/.", "sistema"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GrayLevel", "[", "0.", "]"}], ",", 
      RowBox[{"Dashing", "[", 
       RowBox[{"{", 
        RowBox[{"0.02", ",", "0.02"}], "}"}], "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotLegend", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<y1[t]\>\"", ",", "\"\<y2[t]\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellLabel->"In[30]:="],

Cell["\<\
Vemos que ambas funciones se separan indefinidamente de forma exponencial.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Resolver el sistema  ",
 Cell[BoxData[
  FormBox[
   TagBox[
    StyleBox[
     RowBox[{"{", 
      StyleBox[GridBox[{
         {
          RowBox[{
           RowBox[{
            SubscriptBox["y", "1"], "'"}], "=", 
           SubscriptBox["y", "1"]}]},
         {
          RowBox[{
           RowBox[{
            SubscriptBox["y", "2"], "'"}], "=", 
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["y", "1"]}], "+", 
            RowBox[{"2", 
             SubscriptBox["y", "2"]}]}]}]}
        }],
       ShowAutoStyles->True]}],
     ShowAutoStyles->False],
    #& ], TraditionalForm]]],
 "  con condiciones iniciales ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "1"], "(", "0", ")"}], "=", 
     RowBox[{"-", "1"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["y", "2"], "(", "0", ")"}], "=", "1"}]}], 
   TraditionalForm]]],
 " y representar superpuestas las gr\[AAcute]ficas de ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["y", "1"], "(", "x", ")"}], TraditionalForm]]],
 " e ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["y", "2"], "(", "x", ")"}], TraditionalForm]]],
 " en el intervalo x\[Element][0,10]."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ecuaciones en derivadas parciales", "Subsubsection"],

Cell[TextData[{
 "Finalmente, veamos c\[OAcute]mo introducir una ecuaci\[OAcute]n en \
derivadas parciales como, por ejemplo, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "x"], " ", 
     RowBox[{"U", "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["x", "2"], 
     RowBox[{"y", "/", "z"}]}]}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}], "[", "U", "]"}], "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], "==", 
    RowBox[{
     RowBox[{"x", "^", "2"}], 
     RowBox[{"y", "/", "z"}]}]}], ",", 
   RowBox[{"U", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[33]:="],

Cell[TextData[{
 "que nos da la funci\[OAcute]n ",
 StyleBox["U(x,y,z)=",
  FontSlant->"Italic"],
 Cell[BoxData[
  FractionBox[
   RowBox[{
    SuperscriptBox["x", "3"], " ", "y"}], 
   RowBox[{"3", " ", "z"}]]]],
 StyleBox[" ",
  FontSlant->"Italic"],
 " salvo una funci\[OAcute]n arbitraria ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["C", "1"], "(", 
    RowBox[{"x", ",", "y"}], ")"}], TraditionalForm]]],
 " dependiente de s\[OAcute]lo dos de las tres variables independientes. \
Tambi\[EAcute]n se dispone del paquete: "
}], "Text"],

Cell[BoxData[{
 RowBox[{"<<", "Calculus`DSolveIntegrals`"}], "\[IndentingNewLine]", 
 RowBox[{"CompleteIntegral", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}], "[", "U", "]"}], "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], "==", "yz"}], ",", 
   RowBox[{"U", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], "Input",
 CellLabel->"In[34]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Resuelva la ecuaci\[OAcute]n  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"U", "(", 
        RowBox[{"x", ",", "y"}], ")"}]}]}], "+", 
     RowBox[{"x", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"U", "(", 
        RowBox[{"x", ",", "y"}], ")"}]}]}]}], "=", "0"}], TraditionalForm]]]
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Soluciones num\[EAcute]ricas con NDSolve. E",
  FontFamily->"Times New Roman"],
 "cuaci\[OAcute]n de Van der Pol "
}], "Subsection",
 ShowGroupOpener->True,
 GeneratedCell->False],

Cell[TextData[{
 StyleBox["El comando ",
  FontFamily->"Times New Roman"],
 StyleBox["NDSolve",
  FontFamily->"Courier"],
 " encuentra soluciones num\[EAcute]ricas de ecuaciones diferenciales. \
Selecciona de forma autom\[AAcute]tica el algoritmo \[OAcute]ptimo a usar, o \
nos permite que lo seleccionemos nosotros si lo conocemos previamente. ",
 StyleBox["Mathematica,",
  FontSlant->"Italic"],
 " usa autom\[AAcute]ticamente funciones interpoladoras en vez de listas de n\
\[UAcute]meros para representar las soluciones num\[EAcute]ricas de las \
ecuaciones diferenciales, haciendo m\[AAcute]s factible la \
manipulaci\[OAcute]n posterior de dichas soluciones como, por ejemplo, su \
integraci\[OAcute]n, derivaci\[OAcute]n, etc.\n\nEl comando  ",
 StyleBox["NDSolve ",
  FontFamily->"Courier"],
 " utiliza los siguientes algoritmos:\n\n\[FilledSmallCircle] Por defecto, o \
mediante la opci\[OAcute]n ",
 StyleBox["Method->Automatic", "MR"],
 ", ",
 StyleBox["NDSolve", "MR"],
 " cambia entre un m\[EAcute]todo de Adams no r\[IAcute]gido y un \
m\[EAcute]todo de Adams r\[IAcute]gido adaptado.\n\[FilledSmallCircle] El m\
\[EAcute]todo de Adams se toma con orden entre 1 y 12\n\[FilledSmallCircle] \
El m\[EAcute]todo de la f\[OAcute]rmula de diferencias atrasadas se toma con \
orden entre 1 y 5.\n\[FilledSmallCircle] Un orden  4\[Dash]5 para el m\
\[EAcute]todo Runge\[Hyphen]Kutta se aplica a ecuaciones no r\[IAcute]gidas.\n\
\[FilledSmallCircle] Para problemas lineales con condiciones en la frontera, ",
 StyleBox["NDSolve",
  FontFamily->"Courier"],
 " emplea el m\[EAcute]todo de b\[UAcute]squeda de  \
Gel'fand\[Hyphen]Lokutsiyevskii. \n\[FilledSmallCircle] Para ecuaciones en \
derivadas parciales de dos variables se utiliza el llamado m\[EAcute]todo de \
las lineas.\n\n\nLos algoritmos adaptativos de ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "y su control de una precisi\[OAcute]n arbitraria garantiza la precisi\
\[OAcute]n de los resultados sin errores de redondeo o  soluciones esp\
\[UAcute]reas debidas a errores num\[EAcute]ricos."
}], "Text",
 ShowGroupOpener->True,
 GeneratedCell->False],

Cell[CellGroupData[{

Cell["\<\
Ejemplo: soluci\[OAcute]n num\[EAcute]rica de la ecuaci\[OAcute]n de Van der \
Pol \
\>", "Subsubsection",
 ShowGroupOpener->True,
 GeneratedCell->False],

Cell[TextData[{
 "Veamos c\[OAcute]mo ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "es capaz de proporcionar una soluci\[OAcute]n num\[EAcute]rica para una EDO \
no lineal como la ecuaci\[OAcute]n de Van der Pol\n\n ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "'"}], "'"}], "[", "t", "]"}], "-", 
     RowBox[{"0.2", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"x", "[", "t", "]"}], "2"]}], ")"}], " ", 
      RowBox[{
       RowBox[{"x", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
     RowBox[{"x", "[", "t", "]"}]}], " ", "=", "0"}], TraditionalForm]],
  ShowGroupOpener->True,
  GeneratedCell->False],
 StyleBox[". \n \n ",
  FontSlant->"Italic"],
 "Esta ecuaci\[OAcute]n aparece en el estudio de las oscilaciones de un \
circuito RCL con resistencia ",
 "variable",
 " dependiente de la amplitud ",
 StyleBox["x(t).\n \n ",
  FontSlant->"Italic"],
 "La soluci\[OAcute]n num\[EAcute]rica con velocidad inicial nula ",
 StyleBox["x'(0)=0 ",
  FontSlant->"Italic"],
 "y posici\[OAcute]n inicial  ",
 StyleBox["x(0)=1 ",
  FontSlant->"Italic"],
 " en los primeros 30 segundos (es decir, en el intervalo 0\[LessEqual]t\
\[LessEqual]30) es:"
}], "Text",
 ShowGroupOpener->True,
 GeneratedCell->False],

Cell[BoxData[
 RowBox[{"solu1", " ", "=", " ", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      FormBox[
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"x", "'"}], "'"}], "[", "t", "]"}], "-", 
         RowBox[{"0.2", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"x", "[", "t", "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           RowBox[{"x", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
         RowBox[{"x", "[", "t", "]"}], " "}], "==", "0"}],
       TraditionalForm], ",", 
      RowBox[{
       RowBox[{"x", "[", "0", "]"}], "==", "1"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "'"}], "[", "0", "]"}], "==", "0"}]}], "}"}], ",", "x", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "30"}], "}"}]}], "]"}]}]], "Input",
 ShowGroupOpener->True,
 GeneratedCell->False,
 CellLabel->"In[36]:="],

Cell[TextData[{
 "Podemos verificar que la soluci\[OAcute]n num\[EAcute]rica obtenida \
verifica con bastante precisi\[OAcute]n la ecuaci\[OAcute]n diferencial. En \
efecto, la representaci\[OAcute]n gr\[AAcute]fica de  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"x", "'"}], "'"}], "[", "t", "]"}], "-", 
    RowBox[{"0.2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"x", "[", "t", "]"}], "2"]}], ")"}], " ", 
     RowBox[{
      RowBox[{"x", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
    RowBox[{"x", "[", "t", "]"}], " "}], TraditionalForm]],
  ShowGroupOpener->True,
  GeneratedCell->False],
 " evaluada en la soluci\[OAcute]n ",
 StyleBox["solu1 ",
  FontWeight->"Bold"],
 "anterior "
}], "Text",
 ShowGroupOpener->True,
 GeneratedCell->False],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"x", "'"}], "'"}], "[", "t", "]"}], "-", 
        RowBox[{"0.2", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox[
            RowBox[{"x", "[", "t", "]"}], "2"]}], ")"}], " ", 
         RowBox[{
          RowBox[{"x", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
        RowBox[{"x", "[", "t", "]"}]}], " ", "/.", "solu1"}], "]"}], ",", 
     "3"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "30"}], "}"}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.002"}], ",", "0.002"}], "}"}]}]}], "]"}]], "Input",
 ShowGroupOpener->True,
 GeneratedCell->False,
 CellLabel->"In[37]:="],

Cell[TextData[{
 "nos dice que la soluci\[OAcute]n num\[EAcute]rica ",
 StyleBox["solu1 ",
  FontWeight->"Bold"],
 "verifica la ecuaci\[OAcute]n diferencial en el intervalo t\[Element][0,30] \
salvo errores del orden de 0.001. Una vez que hemos ganado confianza en \
nuestra soluci\[OAcute]n, represent\[EAcute]mosla  en el intervalo escogido:"
}], "Text",
 ShowGroupOpener->True,
 GeneratedCell->False],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "t", "]"}], "/.", "solu1"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "30"}], "}"}]}], "]"}]], "Input",
 ShowGroupOpener->True,
 GeneratedCell->False,
 CellLabel->"In[38]:="],

Cell[TextData[{
 "No queda claro en el gr\[AAcute]fico anterior si dicha soluci\[OAcute]n es \
peri\[OAcute]dica o no. Una representaci\[OAcute]n en el plano de fases: \"",
 StyleBox["v(x) frente a x\" ",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}]}], "}"}], "/.", 
     RowBox[{"solu1", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "30"}], "}"}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}]}]}], "]"}]], "Input",
 ShowGroupOpener->True,
 GeneratedCell->False,
 CellLabel->"In[39]:="],

Cell[TextData[{
 "nos muestra que la \[OAcute]rbita no es cerrada (al menos en el intervalo \
[0,30]), lo que da idea de \"falta de periodicidad\". No obstante, \
n\[OAcute]tese que la \[OAcute]rbita se acerca \"asint\[OAcute]ticamente\" \
(\"a largo plazo\") a una \[OAcute]rbita cerrada \"atractriz\". Para ver este \
comportamiento asint\[OAcute]tico de la \[OAcute]rbita  con mayor nitidez, \
podemos extender el intervalo de tiempo de 30 a 90 segundos y aumentar el n\
\[UAcute]mero m\[AAcute]ximo de pasos que ",
 StyleBox["NDSolve ",
  FontWeight->"Bold"],
 "utiliza (por defecto 500) a 2000 mediante la opci\[OAcute]n ",
 StyleBox["MaxSteps->2000",
  FontWeight->"Bold"],
 " en:"
}], "Text",
 ShowGroupOpener->True,
 GeneratedCell->False],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "x", "]"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "es", " ", "necesario", " ", "borrar", " ", "antes", " ", "el", " ", 
     "valor", " ", "de", " ", "x"}], "*)"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solu2", "=", " ", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FormBox[
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"x", "'"}], "'"}], "[", "t", "]"}], "-", 
          RowBox[{"0.2", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox[
              RowBox[{"x", "[", "t", "]"}], "2"]}], ")"}], " ", 
           RowBox[{
            RowBox[{"x", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
          RowBox[{"x", "[", "t", "]"}], " "}], "==", "0"}],
        TraditionalForm], ",", 
       RowBox[{
        RowBox[{"x", "[", "0", "]"}], "==", "1"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "0", "]"}], "==", "0"}]}], "}"}], ",", "x", 
     ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "90"}], "}"}], ",", 
     RowBox[{"MaxSteps", "->", "2000"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}]}], "}"}], "/.", 
     RowBox[{"solu2", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "90"}], "}"}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}]}]}], "]"}]}], "Input",
 CellLabel->"In[40]:="],

Cell["\<\
Aqu\[IAcute] se observa con mayor nitidez que existe una \[OAcute]rbita \"l\
\[IAcute]mite, asint\[OAcute]tica o atractriz\"  (n\[OAcute]tese la zona de \
mayor densidad de l\[IAcute]neas)  cerrada donde converge (a la cual se \
acerca cada vez m\[AAcute]s)  nuestro sistema. Esto quiere decir que, aunque \
el sistema no sea peri\[OAcute]dico, se comporta como tal a largo plazo (este \
es un caso particular de un teorema general debido a Alfred Li\[EAcute]nard).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ejercicio", "Subsubsection"],

Cell[TextData[{
 "Hallar la soluci\[OAcute]n num\[EAcute]rica de la ecuaci\[OAcute]n de Van \
der Pol con velocidad inicial  ",
 StyleBox["x'(0)=2 ",
  FontSlant->"Italic"],
 "y posici\[OAcute]n inicial  ",
 StyleBox["x(0)=0 ",
  FontSlant->"Italic"],
 " en los primeros 50 segundos (es decir, en el intervalo 0\[LessEqual]t\
\[LessEqual]50)  y representar las gr\[AAcute]ficas: ",
 StyleBox["x-t ",
  FontWeight->"Bold"],
 "(posici\[OAcute]n frente a tiempo) y ",
 StyleBox[" x'-x",
  FontWeight->"Bold"],
 " (velocidad frente a posici\[OAcute]n)."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingStartingPageNumber->109,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      OptionValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      OptionValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"FacingPages"->True,
"FirstPageHeader"->False,
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{72, 72}, {57.5625, 57.5625}}},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Textbook.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 101, 2, 83, "Section"],
Cell[CellGroupData[{
Cell[693, 28, 150, 3, 38, "Subsection"],
Cell[CellGroupData[{
Cell[868, 35, 44, 0, 35, "Subsubsection"],
Cell[915, 37, 1161, 35, 239, "Text"],
Cell[2079, 74, 1180, 25, 112, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3296, 104, 97, 2, 35, "Subsubsection"],
Cell[3396, 108, 775, 26, 39, "Text"],
Cell[4174, 136, 467, 14, 49, "Input"],
Cell[4644, 152, 158, 5, 25, "Text"],
Cell[4805, 159, 220, 7, 30, "Input"],
Cell[5028, 168, 523, 15, 42, "Text"],
Cell[5554, 185, 599, 19, 50, "Input"],
Cell[6156, 206, 184, 4, 25, "Text"],
Cell[6343, 212, 562, 18, 50, "Input"],
Cell[6908, 232, 92, 2, 25, "Text"],
Cell[7003, 236, 121, 3, 30, "Input"],
Cell[7127, 241, 125, 3, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7289, 249, 34, 0, 37, "Subsubsection"],
Cell[7326, 251, 570, 21, 42, "Text"],
Cell[7899, 274, 2148, 53, 110, "Text"],
Cell[10050, 329, 620, 20, 90, "Input"],
Cell[10673, 351, 1708, 61, 42, "Text"],
Cell[12384, 414, 825, 27, 70, "Input"],
Cell[13212, 443, 198, 4, 25, "Text"],
Cell[13413, 449, 677, 22, 50, "Input"],
Cell[14093, 473, 87, 2, 25, "Text"],
Cell[14183, 477, 121, 3, 30, "Input"],
Cell[14307, 482, 823, 29, 42, "Text"],
Cell[15133, 513, 197, 6, 30, "Input"],
Cell[15333, 521, 49, 0, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15419, 526, 34, 0, 37, "Subsubsection"],
Cell[15456, 528, 411, 12, 42, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15904, 545, 71, 0, 37, "Subsubsection"],
Cell[15978, 547, 511, 15, 42, "Text"],
Cell[16492, 564, 428, 14, 50, "Input"],
Cell[16923, 580, 484, 13, 75, "Text"],
Cell[17410, 595, 533, 18, 30, "Input"],
Cell[17946, 615, 429, 15, 26, "Text"],
Cell[18378, 632, 362, 11, 30, "Input"],
Cell[18743, 645, 533, 19, 33, "Text"],
Cell[19279, 666, 427, 14, 35, "Input"],
Cell[19709, 682, 361, 11, 25, "Text"],
Cell[20073, 695, 571, 19, 35, "Input"],
Cell[20647, 716, 311, 7, 75, "Text"],
Cell[20961, 725, 827, 26, 50, "Input"],
Cell[21791, 753, 461, 11, 42, "Text"],
Cell[22255, 766, 570, 19, 35, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22862, 790, 34, 0, 37, "Subsubsection"],
Cell[22899, 792, 839, 32, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23775, 829, 41, 0, 37, "Subsubsection"],
Cell[23819, 831, 768, 27, 56, "Text"],
Cell[24590, 860, 652, 21, 30, "Input"],
Cell[25245, 883, 429, 13, 42, "Text"],
Cell[25677, 898, 1606, 49, 90, "Input"],
Cell[27286, 949, 98, 2, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27421, 956, 34, 0, 37, "Subsubsection"],
Cell[27458, 958, 1258, 49, 39, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28753, 1012, 58, 0, 37, "Subsubsection"],
Cell[28814, 1014, 414, 13, 25, "Text"],
Cell[29231, 1029, 512, 16, 30, "Input"],
Cell[29746, 1047, 552, 19, 32, "Text"],
Cell[30301, 1068, 523, 14, 50, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30861, 1087, 34, 0, 37, "Subsubsection"],
Cell[30898, 1089, 454, 16, 26, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31401, 1111, 206, 6, 44, "Subsection"],
Cell[31610, 1119, 2128, 42, 359, "Text"],
Cell[CellGroupData[{
Cell[33763, 1165, 163, 5, 37, "Subsubsection"],
Cell[33929, 1172, 1309, 41, 175, "Text"],
Cell[35241, 1215, 958, 31, 31, "Input"],
Cell[36202, 1248, 827, 26, 42, "Text"],
Cell[37032, 1276, 866, 28, 31, "Input"],
Cell[37901, 1306, 403, 9, 42, "Text"],
Cell[38307, 1317, 270, 9, 30, "Input"],
Cell[38580, 1328, 239, 5, 25, "Text"],
Cell[38822, 1335, 703, 22, 30, "Input"],
Cell[39528, 1359, 746, 16, 59, "Text"],
Cell[40277, 1377, 1927, 59, 111, "Input"],
Cell[42207, 1438, 489, 7, 42, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42733, 1450, 34, 0, 37, "Subsubsection"],
Cell[42770, 1452, 561, 16, 42, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

